clear; close all; clc;
addpath('../../Documents/MATLAB/altmany-export_fig-cafc7c5/');

load cellseg_20180424_BMP4_psmad15.mat
normfiles = dir('*norm*');


x = handles.Measurements.Nuclei.Location_Center_X;
y = handles.Measurements.Nuclei.Location_Center_Y;
dapi = handles.Measurements.Nuclei.Intensity_UpperQuartileIntensity_DAPI;
sox2 = handles.Measurements.Nuclei.Intensity_UpperQuartileIntensity_SOX2;
psmad = handles.Measurements.Nuclei.Intensity_UpperQuartileIntensity_pSMAD;
psmadmin = handles.Measurements.Nuclei.Intensity_MeanIntensity_pSMAD;

udapi = handles.Measurements.Nuclei.Intensity_MedianIntensity_DAPI;
usox2 = handles.Measurements.Nuclei.Intensity_MedianIntensity_SOX2;
upsmad = handles.Measurements.Nuclei.Intensity_MedianIntensity_pSMAD;

%% CALCULATING AVERAGE CELL SIZE APPROX -- 13m %

intercelldist = zeros(length(x),1);
for i = 1:length(x)
    D = sort(pdist([x{i},y{i}]));
    intercelldist(i) = mean(D(1:length(x{i})))*1.3/2;
end
intercelldistmean = mean(intercelldist);


%% Parameters
%filename =  'sdr-T-E6TL20171026-norm/sdr-T-E6TL20171026_s%02d-norm.tiff';

pdf_normmixture = @(x,p,mu1,mu2,sigma1,sigma2) ...
                         p*normpdf(x,mu1,sigma1) + (1-p)*normpdf(x,mu2,sigma2);
pStart = .7;
lb = [0 -Inf -Inf 0 0];
ub = [1 Inf Inf Inf Inf];
options = statset('MaxIter',100000, 'MaxFunEvals',100000);
maxdist = 0;

logoct = [];
logsox = [];
logdapi = [];
logpsmad = [];

for s=1:length(x)    
    dapi{s} = dapi{s}.*(2^16-1)+1;
    sox2{s} = sox2{s}.*(2^16-1)+1;
    psmad{s} = psmad{s}.*(2^16-1)+1;
    
    udapi{s} = udapi{s}.*(2^16-1)+1;
    usox2{s} = usox2{s}.*(2^16-1)+1;
    upsmad{s} = upsmad{s}.*(2^16-1)+1;
    
    psmadmin{s} = psmadmin{s}*(2^16-1)+1;
    
    logdapi = [logdapi; log(dapi{s})];
    logsox = [logsox; log(sox2{s})];
    logpsmad = [logpsmad; log(psmad{s})];
   
end


for s = 1:length(x)
    s    
    
    %% Filter out Bad 'Cells' from Image Segmentation Results    
    logdapi = log(udapi{s});
    logsox = log(usox2{s});
    logpsmad = log(upsmad{s});
    dapipcells = logdapi>0;%8.1;%4.3;
    
%     imshow(I,[]);
%     hold on;
%     plot(x{1},y{1},'ro');
%     plot(x{1}(dapipcells),y{1}(dapipcells),'bo');


    % Throw out cells below cutoffs %
    keepcells = dapipcells;
    xF = x{s}(keepcells);
    yF = y{s}(keepcells);
    dapiF = dapi{s}(keepcells);
    sox2F = sox2{s}(keepcells);
    psmadF = psmad{s}(keepcells);
    
    % Check filtering %
%     figure;
%     imshow(imread(fullfile(normfiles(s).folder,normfiles(s).name)),[]);
%     hold on;
%     plot(x{s},y{s},'ro');
%     plot(xF,yF,'bo');
%     pause;
%     close;
    
    
    %% Calculate cell density
    r = 100;
    cell_density = sum(squareform(pdist([xF yF])) < r,2);
    xCD = xF(cell_density>4);
    yCD = yF(cell_density>4);
    dapiCD = dapiF(cell_density>4);
    sox2CD = sox2F(cell_density>4);
    psmadCD = psmadF(cell_density>4);
    cell_densityCD = cell_density(cell_density>4);
    
    
    %% Calculate distance from edge
    rpoints = 60; % "empty" points have no cells within a radius of 'rpoints'
    points = rand(100000,2)*1024;
    emptypoints = zeros(length(points),1);
    for p = 1:length(emptypoints)
        emptypoints(p) = all((points(p,1)-xCD).^2 + (points(p,2)-yCD).^2 > rpoints.^2);
    end
    
    if s == 87
        points = [points; 72 431];
        emptypoints = [emptypoints;1];
    end
    if s == 111
        points = [points; 128 879];
        emptypoints = [emptypoints;1];
    end
    if s == 123
         points = [points; 204 253; 274 321; 388, 285; 308, 187];
         emptypoints = [emptypoints;1;1;1;1];
    end
    if s == 133
        points = [points; 288 899];
        emptypoints = [emptypoints;1];
    end
    if s == 135
        points = [points; 934 141; 236, 1013; 42, 1017];
        emptypoints = [emptypoints;1;1;1];
    end
    
    if s == 180
        points = [points; 8 1024];
        emptypoints = [emptypoints;1];
    end
    if s == 191
        points = [points; 22 761];
        emptypoints = [emptypoints;1];
    end
    
    ep = find(emptypoints);
    
              
    distfromedge = zeros(length(xCD),1);
    for j = 1:length(distfromedge)
        d = (xCD(j) - points(ep,1)).^2 +...
            (yCD(j) - points(ep,2)).^2;
        distfromedge(j) = sqrt(min(d))-rpoints;
    end
    distfromedge(distfromedge<0)=0;
    Ecells = distfromedge<40;
    Icells = distfromedge>=120;

    psmadN = zeros(size(psmadCD));
    pSmadbackground = zeros(size(psmadCD));
    for i = 1:length(psmadCD)
        w = 300; % sliding window
        xn = max(xCD(i)-w,1);
        xp = min(xCD(i)+w,1024);
        yn = max(yCD(i)-w,1);
        yp = min(yCD(i)+w,1024);
        windowcells = find((x{s}>xn).*(x{s}<xp).*(y{s}>yn).*(y{s}<yp));
        pSmadbackground(i) = min(psmadmin{s}(windowcells));
        psmadN(i) = psmadCD(i) - pSmadbackground(i);
    end
    psmadN(psmadN<0) = 0;
    %psmadN = psmadCD;

    %% Filter out cells near edge of image
    edgefilter = xCD>rpoints & xCD<(1024-rpoints) & yCD>rpoints & yCD<(1024-rpoints);
    xC{s} = xCD(edgefilter);
    yC{s} = yCD(edgefilter);
    dapiC{s} = dapiCD(edgefilter);
    sox2C{s} = sox2CD(edgefilter);
    psmadC{s} = psmadN(edgefilter);
    distfromedgeC{s} = distfromedge(edgefilter);
    maxdist = max(max(distfromedgeC{s}),maxdist);
    cell_densityC{s} = cell_densityCD(edgefilter);
    
end



save DataAnalysis_20180424_BMP4_psmad15.mat;

load DataAnalysis_20180424_BMP4_psmad15.mat;


conc = handles.Measurements.Image.Metadata_Concentration;
time = handles.Measurements.Image.Metadata_InductionTime;

concnum = str2double(conc);
timenum = str2double(time);

concs = unique(concnum);
timeS = unique(timenum);


N = 40; %number of bins
distBins  = zeros(N,length(concs),length(timeS));
distDapi = zeros(N,length(concs),length(timeS));
distSox2 = zeros(N,length(concs),length(timeS));
distpSmad = zeros(N,length(concs),length(timeS));
distpSmadSox2 = zeros(N,length(concs),length(timeS));
distpSmadI = zeros(N,length(concs),length(timeS),5);
distpSmadCI = zeros(2,N,length(concs),length(timeS));

distpSmadN = distpSmad;

edgelimit = 200;

Nbs = 10000;
edgeDepth_bs = zeros(Nbs,length(concs),length(timeS));

smadcutoff = 7;

for c = 1:length(concs) 
    for t = 1:length(timeS)
        (c-1)*6+t
        
        if c==5 && t==2
            distpSmad(:,5,2) = nan;
            continue
        end
        
        dapiSort = dapiC(find(concnum==concs(c) & timenum==timeS(t)));
        dapiSort = vertcat(dapiSort{:});

        sox2Sort = sox2C(find(concnum==concs(c) & timenum==timeS(t)));
        sox2Sort = vertcat(sox2Sort{:});
        sox2normSort = sox2Sort./dapiSort;

        pSmadSort = psmadC(find(concnum==concs(c) & timenum==timeS(t)));
        pSmadSort = vertcat(pSmadSort{:}); 

        if c == 1
            if t == 1
                [~,pSmaddensity, pSmadmesh,~] = kde(pSmadSort(:),2000);
                [~,pSmadmaxloc] = max(pSmaddensity);
                pSmadmode = pSmadmesh(pSmadmaxloc);  
            end
        end

        pSmadnormSort = pSmadSort./pSmadmode;
       

        distfromedgeSort = distfromedgeC(find(concnum==concs(c) & timenum==timeS(t)));
        distfromedgeSort = vertcat(distfromedgeSort{:});
        [distN,distEdges,distBin] = histcounts(distfromedgeSort, prctile(distfromedgeSort,linspace(0,100,N+1)));
        %[distN,distEdges,distBin] = histcounts(distfromedgeSort, 0:13:(N)*13);
        distBins(:,c,t) = (distEdges(1:end-1)+distEdges(2:end))./2;
        for i = 1:N
            distDapi(i,c,t) = mean(dapiSort(distBin==i));
            distSox2(i,c,t) = mean(sox2normSort(distBin==i));
            distpSmad(i,c,t) = mean(pSmadnormSort(distBin==i));
            [~,~,distpSmadCI(:,i,c,t),~] = ttest(pSmadnormSort(distBin==i));
        end
        
       %% Bootstrapping confidence intervals for edge depth 
        nbs = length(pSmadnormSort);
        for bs = 1:Nbs
            samplebs = ceil(rand(nbs,1)*nbs);
            pSmadnormSort_bs = pSmadnormSort(samplebs);
            distfromedgeSort_bs = distfromedgeSort(samplebs);
            [~,distEdges_bs,distBin_bs] = histcounts(distfromedgeSort_bs, prctile(distfromedgeSort_bs,linspace(0,100,N+1)));
            distBins_bs(:) = (distEdges_bs(1:end-1)+distEdges_bs(2:end))./2;
            for i = 1:N
                distpSmad_bs(i) = mean(pSmadnormSort_bs(distBin_bs==i));
            end
            limitbins_bs = find(distBins_bs(:)<edgelimit);
            j_bs = find((distpSmad_bs(limitbins_bs))>smadcutoff,1,'last'); 
            if ~isempty(j_bs)
                edgeDepth_bs(bs,c,t) = distBins_bs(j_bs);
            end
        end
        
       %%
        
        %distpSmadN(:,c) = distpSmad(:,c)-mean(distpSmad(0.65*distBins(:,c)>110,c))
      
%        for j = 1:5
%            for i = 1:N
%                imind = find(concnum==concs(c) & timenum==timeS(t));
%                [~,~,distBinI] = histcounts(distfromedgeC{imind(j)},distEdges);
%                psmadI = psmadC{imind(j)};
%                distpSmadI(i,c,t,j) = mean(psmadI(distBinI==i)./pSmadmode);  
%            end
%        end
       
       
       
%        F1 = figure(1)
%        hold on;
%        for j = 1:5
%            plot(0.65*distBins(:,c,t),smooth(distpSmadI(:,c,t,j)),'-','Color',[t/length(timeS) 0  0],'LineWidth',2);
%        end
%        xlim([0 0.65*edgelimit]);
%        ylim([0 15]);
%        xlabel('Distance From Edge');
%        ylabel('pSMAD1/5');
% 
%        F2 = figure(2)
%        hold on;
%        shadedErrorBar(0.65*distBins(:,c,t),distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',[t/length(timeS) 0 0]},0.7)
%        %plot(0.65*distBins(:,c,t),smooth(distpSmad(:,c,t)),'-','Color',[t/length(timeS) 0  0],'LineWidth',2);
%        xlim([0 0.65*edgelimit]);
%        ylim([0 15]);
%        xlabel('Distance From Edge');
%        ylabel('pSMAD1/5');
%        pause
%        clf(F1);
       
    end
%     close(F1);
%     close(F2);
end

save('DataAnalysisbs_20180424_BMP4_psmad15.mat');

load('DataAnalysisbs_20180424_BMP4_psmad15.mat');
R = load('ReLeSR_psmad15.mat');




%% Show all curves
figure; 
for c = 1%1:length(concs)
    %subplot(length(concs),1,c);
    hold on;
    for t = 1:length(timeS)     
        %plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',(0.7-0.35*(i-1))*ones(1,3),'LineWidth',2);
        plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',[t/length(timeS) 0  0],'LineWidth',2);
    end
    for t = 1:length(timeS) 
        %shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',(0.7-0.35*(i-1))*ones(1,3), 'LineWidth',2},1)
        shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',[(timeS(t)-timeS(1))/range(timeS) 0 0], 'LineWidth',2},1)  
    end
    xlim([0 10]);%0.65*edgelimit]);
    ylim([0 18]);
    %xlabel('Distance from Edge (Cell Lengths)');
    %ylabel('pSMAD1/5');
    %legend('15 mins', '30 mins', '45 mins', '60 mins', '90 mins');
    %legend('15 mins', '45 mins', '90 mins');
end
%set(gca,'FontSize',20);
%set(gca,'XMinorTick','on');
%set(gca,'YMinorTick','on');


%% Time

% figure; 
% for c = 6%:length(concs)
%     %subplot(length(concs),1,c);
%     hold on;
%     ti = 1:2:length(timeS)-1;
%     for i = 1:3
%         t = ti(i);
%         plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',(0.7-0.35*(i-1))*ones(1,3),'LineWidth',2);
%         %plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',[t/length(timeS) 0  0],'LineWidth',2);
% 
%     end
%     for i = 1:3
%         t = ti(i);
%         shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',(0.7-0.35*(i-1))*ones(1,3), 'LineWidth',2},1)
%         %shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',[(timeS(t)-timeS(1))/range(timeS) 0 0], 'LineWidth',2},1)  
%     end
%     xlim([0 10]);%0.65*edgelimit]);
%     ylim([0 18]);
%     xlabel('Distance from Edge (Cell Lengths)');
%     ylabel('pSMAD1/5');
%     %legend('15 mins', '30 mins', '45 mins', '60 mins', '90 mins');
%     legend('15 mins', '45 mins', '90 mins');
% end
% set(gca,'FontSize',20);
% set(gca,'XMinorTick','on');
% set(gca,'YMinorTick','on');
% print('timeSmad_20180424_BMP4_psmad15.pdf','-dpdf');;
% close;

% colors = [0.8 0.6 0.45 0.3 0];
% figure; 
% for c = 1%:length(concs)
%     hold on;
%     %ti = 1:2:length(timeS)-1;
%     ti = [1,2,4,5,6];
%     for i = 1:5 % for legend labeling
%         t = ti(i);
%         plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',colors(i)*ones(1,3),'LineWidth',2);
%         %plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',[t/length(timeS) 0  0],'LineWidth',2);
%     end
%     for i = 1:5
%         t = ti(i);
%         shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',colors(i)*ones(1,3), 'LineWidth',2},0);
%     end
%     
% %     i = 1;
% %     t = ti(i);
% %     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
% %     i = 2;
% %     t = ti(i);
% %     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
% %     i = 3;
% %     t = ti(i);
% %     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
% %     i = 4;
% %     t = ti(i);
% %     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
% %     i = 5;
% %     t = ti(i);
% %     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
% end
% xlim([0 6]);%0.65*edgelimit]);
% ylim([0 18]);
% xlabel('Distance from Edge (Cell Lengths)');
% ylabel('pSMAD1/5');
% legend('15 mins', '30 mins', '60 mins', '90 mins','120 mins');
% set(gca,'FontSize',20);
% set(gca,'XMinorTick','on');
% set(gca,'YMinorTick','on');
% print('timeSmad_20180424_BMP4_psmad15.pdf','-dpdf');
% close;

colors = [0.8 0.53 0.27 0];
figure; 
for c = 5%:length(concs)
    hold on;
    %ti = 1:2:length(timeS)-1;
    ti = [1,3,5,6];
    %plot(1+0.65*R.distBins(:,2,1,2)./13,(R.distpSmad(:,2,1,2)),'-','Color','b','LineWidth',2);
    for i = 1:4 % for legend labeling
        t = ti(i);
        plot(1+0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',colors(i)*ones(1,3),'LineWidth',2);
        %plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',[t/length(timeS) 0  0],'LineWidth',2);
    end
    
    %shadedErrorBar(1+0.65*R.distBins(:,2,1,2)./13,R.distpSmad(:,2,1,2),abs(R.distpSmadCI(:,:,2,1,2)-[R.distpSmad(:,2,1,2)';R.distpSmad(:,2,1,2)']) ,{'-','Color','b', 'LineWidth',2},0);
    for i = 1:4
        t = ti(i);
        shadedErrorBar(1+0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',colors(i)*ones(1,3), 'LineWidth',2},0);
    end
    
%     i = 1;
%     t = ti(i);
%     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
%     i = 2;
%     t = ti(i);
%     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
%     i = 3;
%     t = ti(i);
%     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
%     i = 4;
%     t = ti(i);
%     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
%     i = 5;
%     t = ti(i);
%     shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'*','Color',(0.8-0.2*(i-1))*ones(1,3), 'LineWidth',2},1);
end



xlim([1 12]);%0.65*edgelimit]);
ylim([0 19]);
xlabel('Distance from Edge (Cell Lengths)');
ylabel('pSMAD1/5');
%legend('Broken Junctions','15 mins', '45 mins','90 mins','120 mins');
legend('15 mins', '45 mins','90 mins','120 mins');
set(gca,'FontSize',20);
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
print('timeSmad_20180424_BMP4_psmad15.pdf','-dpdf');
close;

%% Conc
% figure; 
% for t = 6%:length(concs)
%     %subplot(length(concs),1,c);
%     hold on;
%     ci = [1,3,5,8];
%     for i = 1:4%1:length(concs)
%         c = ci(i);
%         %shadedErrorBar(0.65*distBins(:,c,t),distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',[0 c/length(concs) 0], 'LineWidth',2},0.99)
%         %plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',[0 (log(concs(c))-log(concs(1)))/range(log(concs)) 0],'LineWidth',2);
%         plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',(0.8-0.266*(i-1))*ones(1,3),'LineWidth',2);
%     end
%     for i = 1:4%1:length(concs)
%         c = ci(i);
%         %shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',[0 (log(concs(c))-log(concs(1)))/range(log(concs)) 0], 'LineWidth',2},1)
%         shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',(0.8-0.266*(i-1))*ones(1,3), 'LineWidth',2},0)
%         %plot(0.65*distBins(:,c,t),(distpSmad(:,c,t)),'-','Color',[0 c/length(concs) 0],'LineWidth',2);
%     end
%     xlim([0 10]);%0.65*edgelimit]);
%     ylim([0 20]);
%     xlabel('Distance from Edge (Cell Lengths)');
%     ylabel('pSMAD1/5');
%     %legend('0.5 ng/mL', '1 ng/mL', '2 ng/mL', '3 ng/mL', '5 ng/mL','10 ng/mL','15 ng/mL','20 ng/mL');
%     legend('0.5 ng/mL','2 ng/mL','5 ng/mL','20 ng/mL');
% end
% set(gca,'FontSize',20);
% set(gca,'XMinorTick','on');
% set(gca,'YMinorTick','on');
% print('concSmad_20180424_BMP4_psmad15.pdf','-dpdf');
% close;



%% Edge Depth 
edgeDepth = zeros(length(concs),length(timeS));

for c = 1:length(concs)
    for t = 1:length(timeS)
        
        if c==5 && t==2
            edgeDepth(c,t) = nan;
            continue
        end
        
        limitbins = find(distBins(:,c,t)<edgelimit);
        j = find(smooth(distpSmad(limitbins,c,t))>smadcutoff,1,'last'); 
        if ~isempty(j)
            edgeDepth(c,t) = distBins(j,c,t);
        end
    end
end



edgeDepthCI = zeros(2,length(concs),length(timeS));
for c = 1:length(concs)
    for t = 1:length(timeS)
        edgeDepthCI(:,c,t) = prctile(edgeDepth_bs(:,c,t),[97.5 2.5]);
    end
end

figure; hold on;
for c = 1:length(concs)
    I = ~isnan(edgeDepth(c,:));
    plot(timeS(I),1+0.65./13*edgeDepth(c,I),'-','Color',[0 c/length(concs) 0], 'LineWidth',2);   
end
for c = 1:length(concs)
    I = ~isnan(edgeDepth(c,:));
  
    %plot(timeS(I),0.65*edgeDepth(c,I)./13,'o','Color',[0 c/length(concs) 0]);
    plot(timeS(I),1+0.65./13*edgeDepth(c,I),'-','Color',[0 c/length(concs) 0], 'LineWidth',2);
    shadedErrorBar(timeS(I),1+0.65*edgeDepth(c,I)./13,...
       0.65./13.*abs(permute(edgeDepthCI(:,c,I),[1 3 2])-ones(2,1)*edgeDepth(c,I)),{'-','Color',[0 c/length(concs) 0], 'LineWidth',2},0);
    
end
xlabel('Time (mins)');
ylabel('pSMAD1/5+ Edge Depth (Cells)');
set(gca,'FontSize',20);
set(gca,'LineWidth',2);
set(gca,'XMinorTick','on');
ylim([1 6]);
xlim([15 120]);
legend('0.5 ng/mL','1 ng/mL','2 ng/mL','3 ng/mL','5 ng/mL','10 ng/mL','15 ng/mL','20 ng/mL', 'Location','northwest');
print('concdepthtime_20180424_BMP4_psmad15.pdf','-dpdf');
close;


%ylim([0 60]);

figure; hold on;
for t = 1:length(timeS)
    I = ~isnan(edgeDepth(:,t));
    
    plot(concs(I),0.65*edgeDepth(I,t)./13,'o','Color',[t/length(timeS) 0 0]);
    plot(concs(I),0.65*edgeDepth(I,t)./13,'-','Color',[t/length(timeS) 0 0]);
end
xlabel('BMP Concentration');
set(gca,'XScale','log');
xlim([0.4,22]);
ylabel('pSMAD1/5+ Edge Depth (Cell Lengths)');
set(gca,'FontSize',20);
set(gca,'LineWidth',2);

[~,tedgemax] = max(edgeDepth,[],2);

figure; hold on;
for c = 1:length(concs)
    errorbar(concs(c), 1+0.65./13*edgeDepth(c,tedgemax(c)),...
        0.65./13.*abs((edgeDepthCI(2,c,tedgemax(c)))-edgeDepth(c,tedgemax(c))),...
        0.65./13.*abs((edgeDepthCI(1,c,tedgemax(c)))-edgeDepth(c,tedgemax(c))),'ko','LineWidth',2);
end
xlabel('BMP Concentration');
set(gca,'XScale','log');
xlim([0.25,45]);
ylim([1 7]);
ylabel('pSMAD1/5+ Edge Depth (Cell Lengths)');
set(gca,'FontSize',20);
set(gca,'LineWidth',2);
set(gca,'XTickLabel',[1 10])
export_fig('concdepth_20180424_BMP4_psmad15.pdf','-dpdf');

%%
figure; 
for t = 6%:length(concs)
    %subplot(length(concs),1,c);
    hold on;
    ci = [1,4,5,8];
    for i = 1:4%1:length(concs)
        c = ci(i);
        t = tedgemax(c);
        %shadedErrorBar(0.65*distBins(:,c,t),distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',[0 c/length(concs) 0], 'LineWidth',2},0.99)
        %plot(0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',[0 (log(concs(c))-log(concs(1)))/range(log(concs)) 0],'LineWidth',2);
        plot(1+0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',(0.8-0.266*(i-1))*ones(1,3),'LineWidth',2);
    end
    for i = 1:4%1:length(concs)
        c = ci(i);
        t = tedgemax(c);
        %shadedErrorBar(0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',[0 (log(concs(c))-log(concs(1)))/range(log(concs)) 0], 'LineWidth',2},1)
        shadedErrorBar(1+0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',(0.8-0.266*(i-1))*ones(1,3), 'LineWidth',2},0)
        %plot(0.65*distBins(:,c,t),(distpSmad(:,c,t)),'-','Color',[0 c/length(concs) 0],'LineWidth',2);
    end
    xlim([1 13]);%0.65*edgelimit]);
    ylim([0 20]);
    xlabel('Distance from Edge (Cell Lengths)');
    ylabel('pSMAD1/5');
    %legend('0.5 ng/mL', '1 ng/mL', '2 ng/mL', '3 ng/mL', '5 ng/mL','10 ng/mL','15 ng/mL','20 ng/mL');
    legend('0.5 ng/mL','3 ng/mL','5 ng/mL','20 ng/mL');
end
set(gca,'FontSize',20);
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
print('concSmad_20180424_BMP4_psmad15.pdf','-dpdf');
close;

%% Supp -- all times for each conc

colors = 0.8:-0.8/5:0;
for c = 1:length(concs)
    figure; 
    hold on;
    for t = 1:length(timeS); % for legend labeling
        plot(1+0.65*distBins(:,c,t)./13,(distpSmad(:,c,t)),'-','Color',colors(t)*ones(1,3),'LineWidth',2);
    end
    for t = 1:length(timeS);
        shadedErrorBar(1+0.65*distBins(:,c,t)./13,distpSmad(:,c,t),abs(distpSmadCI(:,:,c,t)-[distpSmad(:,c,t)';distpSmad(:,c,t)']) ,{'-','Color',colors(t)*ones(1,3), 'LineWidth',2},0);
    end
    xlim([1 13]);%0.65*edgelimit]);
    ylim([0 20]);
    xlabel('Distance from Edge (Cells)');
    ylabel('pSMAD1/5');
    legend('15 mins', '30 mins','45 mins','60 mins','90 mins','120 mins');
    set(gca,'FontSize',20);
    set(gca,'XMinorTick','on');
    set(gca,'YMinorTick','on');
    print(strcat('timeSmad',num2str(concs(c)),'_20180424_BMP4_psmad15.pdf'),'-dpdf');
    close;
end


for t = 1:length(timeS)
    I = ~isnan(edgeDepth(:,t));    
    figure; hold on;
    for c = 1:length(concs)
        if I(c)==0
            continue
        end
        errorbar(concs(c), 1+0.65./13*edgeDepth(c,t),...
        0.65./13.*abs((edgeDepthCI(2,c,t))-edgeDepth(c,t)),...
        0.65./13.*abs((edgeDepthCI(1,c,t))-edgeDepth(c,t)),'ko','LineWidth',2);
    end
    xlabel('BMP Concentration');
    set(gca,'XScale','log');
    xlim([0.25,45]);
    ylim([1 7]);
    ylabel('pSMAD1/5+ Edge Depth (Cell Lengths)');
    set(gca,'FontSize',20);
    set(gca,'LineWidth',2);
    set(gca,'XTickLabel',[1 10])
    export_fig(strcat('concdepth',num2str(timeS(t)),'min_20180424_BMP4_psmad15.pdf'));
    close;
end

save('concdepth_20180424_BMP4_psmad15.mat','timeS','concs','edgeDepth','edgeDepthCI');
