clear; close all; clc;

%% Load Data
files = dir('*.txt');
filenames = [files.name];
conc = extractBetween(filenames,'tov-','basal');
concs = str2num(char(conc));
%formatSpec = '%f';
for i = 1:length(concs)
    %fileID = fopen(files(i).name,'r');
    %Ti{i} = fscanf(fileID,formatSpec,[20 40]);
    Ti{i} = table2array(readtable(files(i).name)); %concs in odd columns, % bound receptors in even columns
    Ti{i} = Ti{i}(:,1:40);
    %fclose(fileID);
end

T = cat(1,Ti{:});
%T = T(:,1:40);
[M,N] = size(Ti{1});


Tconc = T(:,1:2:N); % concs are in odd columns
Tconc = Tconc(:);
Tbound = T(:,2:2:N); % %bound receptors in even columns
Tbound = Tbound(:);
Tdist = repmat((1:M)',length(Ti),N/2);
Tdist = Tdist(:);

% We bin cells by percentile according to their distance from source into 9
% bins.
concedges = prctile(Tconc(:),linspace(0,100,10));

% We assume arbitrarily that 50% receptors bound results in pSmad response,
% though this isn't sensitive.
boundedges = [0,50,100]; 

% We bin cells as edge (dedge<2), middle (2<dedge<6), or interior cells
% (dedge>6).
distedges = [0,2,6,M]+0.5;

[~,~,cbins] = histcounts(Tconc,concedges);
[~,~,dbins] = histcounts(Tdist,distedges);
Tcd = dbins + 3 * cbins;
cdedges = 3.5:1:30.5;

pcs = histcounts2(Tconc,Tbound,concedges,boundedges);
Pcs = pcs./sum(pcs(:));
pds = histcounts2(Tdist,Tbound,distedges,boundedges);
Pds = pds./sum(pds(:));
Pc = sum(Pcs,2);
Ps = sum(Pcs,1);
Pd = sum(Pds,2);
pcds = histcounts2(Tcd,Tbound,cdedges,boundedges);
Pcds = pcds./sum(pcds(:));
Pcd = sum(Pcds,2);

Ics = Pcs.*log(Pcs./(Pc*Ps));
Ics(isnan(Ics)) = 0;
MIcs = sum(Ics(:));
Ids = Pds.*log(Pds./(Pd*Ps));
Ids(isnan(Ids)) = 0;
MIds = sum(Ids(:));
Icds = Pcds.*log(Pcds./(Pcd*Ps));
Icds(isnan(Icds)) = 0;
MIcds = sum(Icds(:));
    
hs = -Ps.*log(Ps);
hs(isnan(hs)) = 0;
Hs = sum(hs);

%Uncertainty Coefficient
PROFcs = MIcs./Hs;
PROFds = MIds./Hs;
PROFcds = MIcds./Hs;

%% Bootstrapping Confidence Intervals

Ncells = numel(Tconc);

for i = 1:10000 % Resampling from data 10,000 times with replacement
    i
    Ni = ceil(rand(Ncells,1).* Ncells); % Same sample size N as original data 

    pcs = histcounts2(Tconc(Ni),Tbound(Ni),concedges,boundedges);
    Pcs = pcs./sum(pcs(:));
    pds = histcounts2(Tdist(Ni),Tbound(Ni),distedges,boundedges);
    Pds = pds./sum(pds(:));
    Pc = sum(Pcs,2);
    Ps = sum(Pcs,1);
    Pd = sum(Pds,2);
    pcds = histcounts2(Tcd(Ni),Tbound(Ni),cdedges,boundedges);
    Pcds = pcds./sum(pcds(:));
    Pcd = sum(Pcds,2);

    Ics = Pcs.*log(Pcs./(Pc*Ps));
    Ics(isnan(Ics)) = 0;
    MIcs = sum(Ics(:));
    Ids = Pds.*log(Pds./(Pd*Ps));
    Ids(isnan(Ids)) = 0;
    MIds = sum(Ids(:));
    Icds = Pcds.*log(Pcds./(Pcd*Ps));
    Icds(isnan(Icds)) = 0;
    MIcds = sum(Icds(:));

    hs = -Ps.*log(Ps);
    hs(isnan(hs)) = 0;
    Hs = sum(hs);

    % Proficiencies calculated from Bootstrapping (BS)
    PROFcs_BS(i) = MIcs./Hs;
    PROFds_BS(i) = MIds./Hs;
    PROFcds_BS(i) = MIcds./Hs;
end


% Construct 95% Confidence Intervals (CI) from Bootstrap Percentiles
PROFcs_CI = prctile(PROFcs_BS,[2.5,97.5]);
PROFds_CI = prctile(PROFds_BS,[2.5,97.5]);
PROFcds_CI = prctile(PROFcds_BS,[2.5,97.5]);

%% Plotting Proficiency

%% PLOTTING pSMAD1/5 PROFICIENCY

PROFs = [PROFcs; PROFds; PROFcds];
PROFs_CI = [PROFcs_CI; PROFds_CI; PROFcds_CI];

F = figure;
set(gcf, 'Color', 'w');
F.Position(3) = F.Position(4)*1.61803398875;
B1 = bar(1,PROFcs, 'LineWidth', 1); hold on;
B2 = bar(2,PROFds, 'LineWidth', 1);
B3 = bar(3,PROFcds, 'LineWidth', 1);
B1.FaceColor = [1 1 1];
B1.EdgeColor = [0 0 0];
B2.FaceColor = [0.7 0.7 0.7];
B2.EdgeColor = [0 0 0];
B3.FaceColor = [0.4 0.4 0.4];
B3.EdgeColor = [0 0 0];
er = errorbar(1:3,PROFs,PROFs-PROFs_CI(:,1),PROFs_CI(:,2)-PROFs);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 1]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('Simulated pSMAD1/5');
ylabel('Proficiency (%)');
export_fig PROF_Simulation.pdf;