%% Figure 7c %%
% Steven Zwick, 2017 %

% Unit Conversion for all images -- pixel:micron = 1:1.3 

clear; clc; close all;
addpath('../altmany-export_fig-5be2ca4');

%% Load Image Segmentation Results
load ufluidic-20170208-psmad.mat;
x = handles.Measurements.Nuclei.Location_Center_X;
y = handles.Measurements.Nuclei.Location_Center_Y;
pSmad = handles.Measurements.Nuclei.Intensity_MeanIntensity_pSmad;
DAPI = handles.Measurements.Nuclei.Intensity_MeanIntensity_DAPI;
Oct4 = handles.Measurements.Nuclei.Intensity_MeanIntensity_Oct4;
Sox2 = handles.Measurements.Nuclei.Intensity_MeanIntensity_Sox2;

%% Parameters for all Images
rpoints = 27;
cwidth = 650; %channel width
cslope = 1023./61; %channel slope
cbl = [170,197,215,170,220,190]; %channel bottom left
yuppercutoff = [860,1024,827,822,773];
Dcutoff = 40;

% manual cleaning up of segmentation results
prunecells{1} = [];
prunecells{2} = [209,897; 213,891; 216,720; 217,713; 256,427; 884,321; 878,403;...
    882,412; 878,422; 879,448; 875,455; 881,454; 874,462];
prunecells{3} = [];
prunecells{4} = [];
prunecells{5} = [];

dX = -77;
dY = 33;

%% Loop over Images
pSmadT = [];
maxdist = 0;
distfromedgeT = [];
concT = [];
oct4T = [];
sox2T = [];
xT = [];
yT = [];
EcellsT = [];
IcellsT = [];
PcellsT = [];
pSmadsigmaT = [];

for jj = 1:5
    % 16 bit pixel values
    Oct4{jj} = Oct4{jj}.*(2.^16);
    Sox2{jj} = Sox2{jj}.*(2.^16);
    DAPI{jj} = DAPI{jj}.*(2.^16);
    pSmad{jj} = pSmad{jj}.*(2.^16);
    
    %% Filter out Bad 'Cells' from Image Segmentation Results
    OctSox = sqrt(Oct4{jj}.^2 + Sox2{jj}.^2);
    
    pdf_normmixture = @(x,p,mu1,mu2,sigma1,sigma2) ...
                         p*normpdf(x,mu1,sigma1) + (1-p)*normpdf(x,mu2,sigma2);
    pStart = .7;
    muStart = quantile(OctSox,[.25 .75]);
    sigmaStart = sqrt(var(OctSox))./2;
    start = [pStart muStart sigmaStart sigmaStart];
    lb = [0 -Inf -Inf 0 0];
    ub = [1 Inf Inf Inf Inf];
                      
    options = statset('MaxIter',1000, 'MaxFunEvals',1000);
    paramEsts = mle(OctSox, 'pdf',pdf_normmixture, 'start',start, ...
                          'lower',lb, 'upper',ub, 'options',options);
                      
    xgrid = linspace(0.9*min(OctSox),1.1*max(OctSox),200);
    pdfgrid = pdf_normmixture(xgrid,paramEsts(1),paramEsts(2),paramEsts(3),paramEsts(4),paramEsts(5));
    [mindumb,minloc] = min(pdfgrid(find(xgrid>paramEsts(2),1):find(xgrid<paramEsts(3),1,'last')));
    octsoxcutoff = xgrid(minloc+sum(xgrid<=paramEsts(2)));
    keepcells = find((y{jj}>1024-(x{jj}-cbl(jj))*cslope)...
        .*(y{jj}<1024-(x{jj}-(cbl(jj)+cwidth))*cslope)...
        .*(OctSox > octsoxcutoff));
    xF = x{jj}(keepcells);
    yF = y{jj}(keepcells);
    pSmadF = pSmad{jj}(keepcells);
    oct4F = Oct4{jj}(keepcells);
    sox2F = Sox2{jj}(keepcells);
    DAPIF = DAPI{jj}(keepcells);
    
    %% Show Filtered Segmentation Results
    %% Calculate Distance from Edge
    points = rand(100000,2)*1023+1;
    emptypoints = zeros(length(points),1);
    for p = 1:length(emptypoints)
        emptypoints(p) = all((points(p,1)-xF).^2 + (points(p,2)-yF).^2 > rpoints.^2);
    end
    if jj ==2
        points = [points;588,811];
        emptypoints = [emptypoints;1];
    end
    ep = find(emptypoints);

    distfromedge = zeros(length(xF),1);
    for j = 1:length(distfromedge)
        d = (xF(j) - points(ep,1)).^2 +...
            (yF(j) - points(ep,2)).^2;
        distfromedge(j) = sqrt(min(d))-rpoints;
    end
    distfromedge(distfromedge<0)=0;
    maxdist =max(maxdist,max(distfromedge));
    Ecells = distfromedge<20;
    Icells = distfromedge>60;
    
    %% Show Distance from Edge Results
    %     figure(2);
    %     imshow(imadjust(imread(sprintf('ufluidic-20170208-psmad15-p2_s%d_c2.tif',jj))));
    %     hold on;
    %     scatter(points(:,1),points(:,2),'g','filled');
    %     scatter(points(ep,1),points(ep,2),'r','filled');
    %     scatter(xF, yF);
    %     set(gcf, 'Position', get(0, 'Screensize'));
    %     set(gca,'FontSize',26);
    %     imagename = sprintf('ufluidic-20170208_s%d-colonyedges.pdf',jj);
    %     export_fig(imagename);
    %     close;

    %     figure(2);
    %     imshow(imadjust(imread(sprintf('ufluidic-20170208-psmad15-p2_s%d_c2.tif',jj))));
    %     hold on;
    %     scatter(lcxF, lcyF, 25, maxdist-distfromedge, 'filled')
    %     colormap cool
    %     caxis([0 maxdist-min(distfromedge)]);
    %     continue

    
    %% Calibrate Local Gradient Levels
    Iconc = imread(sprintf('ufluidic-20170208-gradient/ufluidic-20170208-grad_s%d_c3.tif',jj));
    Iconc = double(Iconc);
    Iconc = (Iconc-min(Iconc(:)))./range(Iconc(:));
    Iconcfilt = imgaussfilt(Iconc,30);% HOW TO DETERMINE FILTER LENGTH??
    
    % determine gradient of cropped image
    Iconccrop = fliplr(imrotate(Iconc,3.186));
    Iconccrop = Iconccrop(46:910,231:775);
    Iconccrop = Iconccrop(1:545,40:471);
    
    Y = max(min(yF+dY,1024),1);
    X = max(min(xF+dX,1024),1);
    conc = Iconcfilt(sub2ind(size(Iconcfilt),round(Y),round(X)));
    conc(conc<0) = 0;
    conc(conc>1) = 1;

    %% Show Gradient Calibration Results
    %% Subtracting Background Fluorescence  
    pSmadN = zeros(size(pSmadF));
    pSmadbackground = zeros(size(pSmad{jj}));
    for i = 1:length(pSmadF)
        w = 50; % sliding window??
        xn = max(xF(i)-w,1);
        xp = min(xF(i)+w,1024);
        yn = max(yF(i)-w,1);
        yp = min(yF(i)+w,1024);
        windowcells = find((x{jj}>xn).*(x{jj}<xp).*(y{jj}>yn).*(y{jj}<yp));
        pSmadbackground(i) = min(pSmad{jj}(windowcells));
        pSmadN(i) = pSmadF(i) - pSmadbackground(i);
    end
    pSmadN(pSmadN<0) = 0;
    
    %% Showing Background Fluorescence Results 
    %     figure;
    %     scatter(x{jj}, 1025-y{jj},125, pSmadbackground, 'filled')
    %     colormap cool
    %     title('Background Intensity');
    %     
    %     figure;
    %     scatter(x{jj}, 1025-y{jj},125, pSmad{jj}, 'filled')
    %     colormap cool
    %     title('Without Background Correction');
    %     
    %     figure;
    %     scatter(x{jj}, 1025-y{jj},125, pSmadN, 'filled')
    %     colormap cool
    %     title('With Background Correction');

    %% Determine Which Cells are pSmad+
    [~,pSmaddensity, pSmadmesh, ~] = kde(pSmadN,1400);
    pSmadmaxloc = find(pSmaddensity==max(pSmaddensity));
    pSmadmax = pSmadmesh(pSmadmaxloc);
    pSmadNhalfnull =pSmadmax-pSmadN(pSmadN<=pSmadmax);
    param = fitdist(pSmadNhalfnull,'HalfNormal');
    fullnulldist = makedist('Normal',pSmadmax,param.sigma);
    Pcells = pSmadN>(pSmadmax+10.*param.sigma);

    %% Show pSmad+ Cell Identification
%     figure;
%     histogram(pSmadN,0:10:max(pSmadN)+10,'Normalization','pdf');
%     hold on;
%     pSmadNnull = pdf(fullnulldist,0:1:max(pSmadN));
%     plot(0:1:max(pSmadN),pSmadNnull);
    
    figure;
    imshow(imadjust(imread(sprintf('ufluidic-20170208-stain/ufluidic-20170208-psmad15-p2_s%d_c4.tif',jj))));
    hold on;
    plot(xF(Pcells),yF(Pcells),'ro');
    
%     figure;
%     imshow(imadjust(imread(sprintf('ufluidic-20170208-psmad15-p2_s%d_c2.tif',jj))));
%     hold on;
%     scatter(x{jj}, y{jj})
%     scatter(xF,yF);
%     set(gcf, 'Position', get(0, 'Screensize'));
%     set(gca,'FontSize',26);
%     imagename = sprintf('ufluidic-20170208_s%d-filteredcells.pdf',jj);
%     export_fig(imagename);
%     close;

%     kde(pSmadF,2000); hold on;
%     plot([pSmadmax,pSmadmax],[0,2.5.*10^-7],'r--');
%     plot(pSmadmesh,pdf(fullnulldist,pSmadmesh)./1.85,'r-.', 'LineWidth',2);
%     plot([pSmadmax+10.*param.sigma,pSmadmax+10.*param.sigma],[0,0.014],'k-.','LineWidth',2);
%     xlim([0,400]);
%     xlabel('pSmad ');
%     ylabel('Probability Density');
%     set(gcf, 'Position', get(0, 'Screensize'));
%     set(gca,'FontSize',26);
%     %imagename = sprintf('ufluidic-20170208_s%d-TFNkdecutoff.pdf',jj);
%     %export_fig(imagename);
%     close;
    
    %% Final Crop of Image to prevent overlap
    finalcells = yF < yuppercutoff(jj);
    xc = xF(finalcells);
    xT = [xT; xc];
    yc = yF(finalcells);
    yT = [yT; yc];
    pSmadN = pSmadN./DAPIF;
    pSmadc = pSmadN(finalcells);
    pSmadsigma = (pSmadc-pSmadmax)./param.sigma;
    pSmadsigmaT = [pSmadsigmaT; pSmadsigma];
    pSmadT = [pSmadT; pSmadc];
    distfromedgec = distfromedge(finalcells);
    distfromedgeT = [distfromedgeT; distfromedgec];
    oct4c = oct4F(finalcells);
    oct4T = [oct4T; oct4c];
    sox2c = sox2F(finalcells);
    sox2T = [sox2T; sox2c];
    concc = conc(finalcells);
    concT = [concT; concc];
    Ecellsc = Ecells(finalcells);
    EcellsT = [EcellsT; Ecellsc];
    Icellsc = Icells(finalcells);
    IcellsT = [IcellsT; Icellsc];
    Pcellsc = Pcells(finalcells);
    PcellsT = [PcellsT; Pcellsc];
    
%     figure(65);
%     imshow(imadjust(imread(sprintf('ufluidic-20170208-psmad15-p2_s%d_c4.tif',jj))));
%     hold on;
%     scatter(xc(distfromedgec<Dcutoff-20),yc(distfromedgec<Dcutoff-20),'mo');
%     scatter(xc(distfromedgec>Dcutoff+20),yc(distfromedgec>Dcutoff+20),'bo');    
%     set(gcf, 'Position', get(0, 'Screensize'));
%     set(gca,'FontSize',26);
%     imagename = sprintf('ufluidic-20170208_s%d-cutoffs.pdf',jj);
%     export_fig(imagename);
%     close;
    
%     F4 = figure(4);
%     set(F4, 'Color', 'w');
%     [lcxM,edges,bin] = histcounts(concc);
%     nbins = max(bin);
%     Ecells = distfromedgec<Dcutoff;
%     Icells = distfromedgec>=Dcutoff;
%     pSmadE = zeros(nbins,1);
%     pSmadI = zeros(nbins,1);
%     for i = 1:nbins    
%         pSmadE(i) = mean(pSmadc(bin==i & Ecells));
%         pSmadI(i) = mean(pSmadc(bin==i & Icells));
%         pSmadEstd(i) = std(pSmadc(bin==i & Ecells));
%         pSmadIstd(i) = std(pSmadc(bin==i & Icells));
%     end
%     edgecenters = (edges(2:nbins+1)+edges(1:nbins))./2;
%     [pSmadhist,pSmadedges,pSmadbin] = histcounts(pSmadC);

%     title('Gradient Level vs pSmad');
%     errorbar(edgecenters(pSmadI>0)+0.05.*diff(edgecenters(1:2)),pSmadE(pSmadI>0),pSmadEstd(pSmadI>0),'m','LineWidth',2);
%     hold on;
%     errorbar(edgecenters(pSmadI>0),pSmadI(pSmadI>0),pSmadIstd(pSmadI>0),'b','LineWidth',2);   
%     % xlim([edgecenters(find(Sox2I>0,1)) ...
%     %     edgecenters(find(Sox2I>0,1,'last'))+0.01]);
%     ylim([prctile(pSmadc,1)-0.0005 prctile(pSmadc,99)+0.0005]);
%     xlabel('Gradient Level');
%     ylabel('pSmad Level');
%     legend('Edge of Colony','Interior of Colony');
%     %set(gca,'yscale','log');
%     set(gcf, 'Position', get(0, 'Screensize'));
%     set(gca,'FontSize',26);
%     imagename = sprintf('ufluidic-20170208_s%d-gradSmadhist.pdf',jj);
%     export_fig(imagename);
%     close;

%     figure
%     [lcxM,edges,bin] = histcounts(concc,0:0.05:1);
%     nbins = max(bin);
%     Ecells = distfromedgec<Dcutoff-20;
%     Icells = distfromedgec>=Dcutoff+20;
%     pSmadE = zeros(nbins,1);
%     pSmadI = zeros(nbins,1);
%     for i = 1:nbins    
%         pSmadE(i) = mean(pSmadsigma(bin==i & Ecells));
%         pSmadI(i) = mean(pSmadsigma(bin==i & Icells));
%         pSmadEstd(i) = std(pSmadsigma(bin==i & Ecells));
%         pSmadIstd(i) = std(pSmadsigma(bin==i & Icells));
%     end
%     edgecenters = (edges(2:nbins+1)+edges(1:nbins))./2;
% 
%     errorbar(edgecenters(pSmadI>0)+0.05.*diff(edgecenters(1:2)),pSmadE(pSmadI>0),pSmadEstd(pSmadI>0),'m','LineWidth',2);
%     hold on;
%     errorbar(edgecenters(pSmadI>0),pSmadI(pSmadI>0),pSmadIstd(pSmadI>0),'b','LineWidth',2);   
%     xlabel('Gradient Level');
%     ylabel('pSmad1/5');
%     legend('Edge of Colony','Interior of Colony','Location','northwest');
%     xlim([0,1])
end

%% Bin Cells by Concentration
%[~,edges,bin] = histcounts(concT,linspace(0,1,13)); %did this for MI plot
[~,edges,bin] = histcounts(concT,prctile(concT,0:100/9:100));
%[~,edges,bin] = histcounts(concT,linspace(0,1,5));
edgecenters = (edges(2:end)+edges(1:end-1))./2;

% Only Analyze Bins with >=5 Interior cells
binI = bin(find(IcellsT));
[bincountsI,~,~] = histcounts(binI);
binsA = unique(binI);
binsA = binsA(bincountsI>=5); %only keep bins with 5 or more interior cells
nbins = length(binsA);

% Only Keep Cells in Analysis Bins
Ccells = ismember(bin,binsA);
concC = concT(Ccells);
xC = xT(Ccells);
yC = yT(Ccells);
oct4C = oct4T(Ccells);
sox2C = sox2T(Ccells);
pSmadC = pSmadT(Ccells);
pSmadsigmaC = pSmadsigmaT(Ccells);
ECcells = EcellsT(Ccells);
ICcells = IcellsT(Ccells);
PCcells = PcellsT(Ccells);
binC = bin(Ccells);

% Only Keep Exterior/Interior Cells in Analysis Bins
Acells = ECcells | ICcells;
concA = concC(Acells);
xA = xC(Acells);
yA = yC(Acells);
oct4A = oct4C(Acells);
sox2A = sox2C(Acells);
pSmadA = pSmadC(Acells);
pSmadsigmaA = pSmadsigmaC(Acells);
EAcells = ECcells(Acells);
IAcells = ICcells(Acells);
PAcells = PCcells(Acells);
PEcells = PAcells & EAcells;
PIcells = PAcells & IAcells;
binA = binC(Acells);

[~,pSmadAdensity, pSmadAmesh,~] = kde(pSmadA(:),5000);
[~,pSmadAmaxloc] = max(pSmadAdensity(pSmadAmesh<1050));
pSmadAmode = pSmadAmesh(pSmadAmaxloc);
pSmadA = pSmadA./pSmadAmode;


%% Show Cells Picked for Analysis (?)
%% Find Mean pSmad Levels of Exterior and Interior Cells at each Concentration Bin
pSmadE = zeros(1,nbins);
pSmadI = zeros(1,nbins);
pSmadEci = zeros(2,nbins);
pSmadIci = zeros(2,nbins);
for i = 1:nbins    
    pSmadE(i) = mean(pSmadA(binA==binsA(i) & EAcells));
    pSmadI(i) = mean(pSmadA(binA==binsA(i) & IAcells));
    [~,~,pSmadEci(:,i),~] = ttest(pSmadA(binA==binsA(i) & EAcells));
    [~,~,pSmadIci(:,i),~] = ttest(pSmadA(binA==binsA(i) & IAcells));
end

F4 = figure;
%set(gcf, 'Position', get(0, 'Screensize'));
set(gcf, 'Color', 'w');
F4.Position(3) = F4.Position(4)*1.61803398875*0.8;
PI = errorbar(edgecenters(binsA),pSmadI,pSmadI-pSmadIci(1,:),pSmadIci(2,:)-pSmadI,'k-o','LineWidth',2,'MarkerSize',2,'MarkerFaceColor','k');   
hold on;
PE = errorbar(edgecenters(binsA)+0.05.*diff(edgecenters(1:2)),pSmadE,pSmadE-pSmadEci(1,:),pSmadEci(2,:)-pSmadE,'-o','LineWidth',2,'MarkerSize',2, 'Color',[0.5 0.5 0.5]);
set(gca,'LineWidth',2);
set(gca,'FontSize',30);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pct = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pct];
set(gca,'xticklabel',new_xticks);
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Mean pSmad1/5 Level');
%legend([PE,PI],'Edge of Colony','Interior of Colony','Location','northwest');
export_fig ufluidic-20170208_gradSmadhist.pdf;
close;

%% Find pSmad Deviations Above Null of Exterior and Interior Cells at each Concentration Bin
pSmadE = zeros(1,nbins);
pSmadI = zeros(1,nbins);
pSmadEci = zeros(2,nbins);
pSmadIci = zeros(2,nbins);
for i = 1:nbins    
    pSmadE(i) = mean(pSmadsigmaA(binA==binsA(i) & EAcells));
    pSmadI(i) = mean(pSmadsigmaA(binA==binsA(i) & IAcells));
    [~,~,pSmadEci(:,i),~] = ttest(pSmadsigmaA(binA==binsA(i) & EAcells));
    [~,~,pSmadIci(:,i),~] = ttest(pSmadsigmaA(binA==binsA(i) & IAcells));
end

figure;
set(gcf, 'Position', get(0, 'Screensize'));
set(gcf, 'Color', 'w');
PI = errorbar(edgecenters(binsA),pSmadI,pSmadI-pSmadIci(1,:),pSmadIci(2,:)-pSmadI,'b-o','LineWidth',2);   
hold on;
PE = errorbar(edgecenters(binsA)+0.05.*diff(edgecenters(1:2)),pSmadE,pSmadE-pSmadEci(1,:),pSmadEci(2,:)-pSmadE,'m-o','LineWidth',2);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pct = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pct];
set(gca,'xticklabel',new_xticks);
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('pSmad1/5 Deviations Above Null Distribution');
legend([PE,PI],'Edge of Colony','Interior of Colony','Location','northwest');
set(gca,'FontSize',26);
export_fig ufluidic-20170208_gradSmadsigma.pdf;
close;

%% Find pSmad Deviations Above Null of Exterior and Interior Cells at each Concentration Bin
pSmadE = zeros(1,nbins);
pSmadI = zeros(1,nbins);
pSmadEci = zeros(2,nbins);
pSmadIci = zeros(2,nbins);
for i = 1:nbins    
    [pSmadE(i), pSmadEci(:,i)] = binofit(sum(binA==binsA(i) & PEcells),sum(binA==binsA(i) & EAcells));
    [pSmadI(i), pSmadIci(:,i)] = binofit(sum(binA==binsA(i) & PIcells),sum(binA==binsA(i) & IAcells));
end

figure;
set(gcf, 'Position', get(0, 'Screensize'));
set(gcf, 'Color', 'w');
PI = errorbar(edgecenters(binsA),pSmadI,pSmadI-pSmadIci(1,:),pSmadIci(2,:)-pSmadI,'b-o','LineWidth',2);   
hold on;
PE = errorbar(edgecenters(binsA)+0.05.*diff(edgecenters(1:2)),pSmadE,pSmadE-pSmadEci(1,:),pSmadEci(2,:)-pSmadE,'m-o','LineWidth',2);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pct = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pct];
set(gca,'xticklabel',new_xticks);
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Probability of pSmad1/5+ Cell');
legend([PE,PI],'Edge of Colony','Interior of Colony','Location','northwest');
set(gca,'FontSize',26);
export_fig ufluidic-20170208_gradSmadprob.pdf;
close;


%% Mutual information
%c = conc
%d = dist
%s = smad

save('Fig1dBins.mat','xC','concC','binC','ECcells','ICcells','PCcells');


% nbins = 1:100;
% MIcs = zeros(length(nbins),1);
% MIds = zeros(length(nbins),1);
% for i = 1:length(nbins)
%     pcs = histcounts2(concT,pSmadT,nbins(i));
%     Pcs = pcs./sum(pcs(:));
%     pds = histcounts2(distfromedgeT,pSmadT,nbins(i));
%     Pds = pds./sum(pds(:));
%     Pc = sum(Pcs,2);
%     Pd = sum(Pds,2);
%     Ps = sum(Pcs,1);
% 
%     Ics = Pcs.*log(Pcs./(Pc*Ps));
%     Ics(isnan(Ics)) = 0;
%     MIcs(i) = sum(Ics(:));
% 
%     Ids = Pds.*log(Pds./(Pd*Ps));
%     Ids(isnan(Ids)) = 0;
%     MIds(i) = sum(Ids(:));
% end
% 
% figure; hold on;
% plot(nbins,MIcs,'g','LineWidth', 4);
% plot(nbins,MIds,'m','LineWidth', 4);
% xlabel('Number of Data Bins');
% ylabel('Mutual Information with pSmad1/5 Level');
% legend('Signal Level','Distance from Edge');


% Cedges = prctile(distfromsourceT,linspace(0,100,40));
% Dedges = prctile(distfromedgeT,linspace(0,100,40));
% [~,~,Cbins] = histcounts(distfromsourceT,Cedges);
% [~,~,Dbins] = histcounts(distfromedgeT,Dedges);
% [C,D] = meshgrid(Cedges,Dedges);
% PS = zeros(length(Cedges),length(Dedges));
% for i = 1:size(PS,1)
%     for j=1:size(PS,2)
%         PS(i,j) = (mean((pSmadT(Cbins==i & Dbins==j))));
%     end
% end
% PS(isnan(PS))=0;
% 
% Ccenters = (Cedges(2:end)+Cedges(1:end-1))./2;
% Dcenters = (Dedges(2:end)+Dedges(1:end-1))./2;

%PS = flipud(PS)
%PS = log(PS);
% figure
% surf(C*1000,D,PS');
% view(2);
% colorbar
% caxis([0.1 0.35])
% ylabel('Distance from Edge');
% xlabel('Distance from Source');
% ylim([0 100]);
% colormap hot

distfromedgeT = distfromedgeT.*1.3;
distfromsourceT = (1-concT).*1000;
%distfromsourceT = xT;

N = 200; % coarseness of heatmap
m = 40; % number of cells to average
PSsmooth = zeros(N);
Cedg = linspace(0,1000,N);
Dedg = linspace(0,max(distfromedgeT),N);

for i=1:N
    i
    for j=1:N
        ci = Cedg(i)./max(Cedg);
        di =Dedg(j)./max(Dedg);
        disti = (distfromsourceT./max(distfromsourceT)-ci).^2+(distfromedgeT./max(distfromedgeT)-di).^2;
        [~,sorti] = sort(disti);
        cellsi = sorti(1:m);
        PSsmooth(j,i) = mean(pSmadT(cellsi));
    end
end

figure;
imagesc(PSsmooth,'Xdata',Cedg,'Ydata',Dedg);
set(gca,'YDir','normal');
colorbar
colormap hot
ylabel('Distance from Edge');
xlabel('Distance from Source');
caxis([0.07 0.22])
ylim([0,200]);
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
export_fig smadheatmap.pdf;





% %%  OctSox FACS, Distance from Edge
% 
%     
% Ecells = distfromedgeD<100;
% 
% [n,~] = size(sox2D);
% bin = zeros(n,2);
% [~,bin(:,2)] = histc(log(sox2D),edgesSox2);
% [~,bin(:,1)] = histc(log(oct4D),edgesOct4);
% H = accumarray(bin,1,nbins([2 1])) ./ n;
% G = smooth1D(H,nbins(2)/lambda);
% F = smooth1D(G',nbins(1)/lambda)';
% Fnorm = F./sum(F(:));
% F = F./max(F(:));
% %     
% %     [n,~] = size(sox2D(Ecells));
% %     binE = zeros(n,2);
% %     [~,binE(:,2)] = histc(log(sox2D(Ecells)),edgesSox2);
% %     [~,binE(:,1)] = histc(log(oct4D(Ecells)),edgesOct4);
% %     HE = accumarray(binE,1,nbins([2 1])) ./ n;
% %     GE = smooth1D(HE,nbins(2)/lambda);
% %     FE = smooth1D(GE',nbins(1)/lambda)';
% %     FEnorm = FE./sum(FE(:));
% % 
% %     [n,~] = size(sox2D(~Ecells));
% %     binI = zeros(n,2);
% %     [~,binI(:,2)] = histc(log(sox2D(~Ecells)),edgesSox2);
% %     [~,binI(:,1)] = histc(log(oct4D(~Ecells)),edgesOct4);
% %     HI = accumarray(binI,1,nbins([2 1])) ./ n;
% %     GI = smooth1D(HI,nbins(2)/lambda);
% %     FI = smooth1D(GI',nbins(1)/lambda)';
% %     FInorm = FI./sum(FI(:));
% %     
% %     Fdiff = FEnorm-FInorm;
% %     Fdiff = Fdiff./0.0003;
% %     ind = sub2ind(size(F),bin(:,1),bin(:,2));
% %     col = Fdiff(ind);
% % 
%     h = figure;
%     set(gcf, 'Position', get(0, 'Screensize'));
%     imagesc(ctrsSox2,ctrsOct4,Fdiff);
%     set(gcf,'Color','k');
%     set(gca,'Color','k');
%     set(gca,'FontSize',26);
%     set(gca,'XMinorTick','on');
%     set(gca,'YMinorTick','on');
%     set(gca, 'XColor', [1 1 1]);
%     set(gca, 'YColor', [1 1 1]);
%     colormap(bmmap);
%     caxis([-1 1]);
%     xlim([0 7]);
%     ylim([0 9]); 
%     set(gca,'YDir','normal');
%     hold on;
%     contour(ctrsSox2,ctrsOct4,F,10,'LineWidth',0.5,'LineColor','w');
%     C = colorbar;
%     set(C,'Color','w');
%     C.Ticks = [-1,0,1];
%     xlabel(C,'$$ P(Oct4,Sox2|ExteriorCell)-P(Oct4,Sox2|InteriorCell) $$','Interpreter','latex');
%     plot([soxcutoff,soxcutoff],[0,10],'w--');
%     plot([0,10],[octcutoff,octcutoff],'w--');
%     xlabel('Log Sox2 Level (A.U.)'); 
%     ylabel('Log Oct4 Level (A.U.)');

