%% Figure 7dh %%
clear; close all; clc;


%% pSMAD1/5 PROFICIENCY %%

load('../Fig1d/Fig1dBins.mat');
Ccells = binC; %cells binned by percentile Dsource (BMP concentration)into 9 bins
Ecells = ECcells; % edge cells 
Icells = ICcells; % interior cells 
Mcells = ~(ECcells|ICcells); % cells that are neither on edge nor interior
Dcells = Ecells + 2*Mcells + 3*Icells; % indexing cells by Dedge
Pcells = PCcells; % pSMAD1/5(+) cells
CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource

pcs = histcounts2(Ccells,Pcells); % 9x2 frequency bin of pSMAD1/5-negative/positive cells at different Dsource
Pcs = pcs./sum(pcs(:)); % frequency bin --> probability bin
pds = histcounts2(Dcells,Pcells); % 3x2 frequency bin of pSMAD1/5-negative/positive cells at different Dedge
Pds = pds./sum(pds(:)); %3x2 frequency bin --> 3x2 probability bin
Pc = sum(Pcs,2); %marginal probability P(Dsource)
Pd = sum(Pds,2); %marginal probability P(edge/middle/interior)
Ps = sum(Pcs,1); %marginal probability P(pSMAD1/5(-)/(+))

pcds = histcounts2(CDcells,Pcells); %27x2 frequency bin of pSMAD1/5-negative/positive cells at different Dsource and Dedge 
Pcds = pcds./sum(pcds(:)); %27x2 frequency bin --> 27x2 probability bin
Pcd = sum(Pcds,2); %27x1 marginal probability P(Dsource and Dedge)

Ics = Pcs.*log(Pcs./(Pc*Ps));
MIcs = sum(Ics(:)); % Mutual Information btwn Dsource and pSMAD1/5
Ids = Pds.*log(Pds./(Pd*Ps));
MIds = sum(Ids(:)); % Mutual Information btwn Dedge and pSMAD1/5
Icds = Pcds.*log(Pcds./(Pcd*Ps));
Icds(isnan(Icds)) = 0;
MIcds = sum(Icds(:)); % Mutual Information btwn (Dsource AND Dedge) and pSMAD1/5

Hs = -sum(Ps.*log(Ps)); % Entropy of pSMAD1/5

PROFcs = MIcs./Hs; % Proficiency btwn Dsource and pSMAD1/5
PROFds = MIds./Hs; % Proficiency btwn Dedge and pSMAD1/5
PROFcds = MIcds./Hs; % Proficiency btwn (Dsource AND Dedge) and pSMAD1/5



%% BOOTSTRAPPING CONFIDENCE INTERVALS 

N = length(Ccells);

for i = 1:10000 % Resampling from data 10,000 times with replacement
    i
    Ni = ceil(rand(N,1).* N); % Same sample size N as original data 

    pcs = histcounts2(Ccells(Ni),Pcells(Ni)); 
    Pcs = pcs./sum(pcs(:)); 
    pds = histcounts2(Dcells(Ni),Pcells(Ni)); 
    Pds = pds./sum(pds(:)); 
    Pc = sum(Pcs,2); 
    Pd = sum(Pds,2); 
    Ps = sum(Pcs,1); 

    pcds = histcounts2(CDcells(Ni),Pcells(Ni));  
    Pcds = pcds./sum(pcds(:)); 
    Pcd = sum(Pcds,2); 

    Ics = Pcs.*log(Pcs./(Pc*Ps));
    MIcs = sum(Ics(:)); 
    Ids = Pds.*log(Pds./(Pd*Ps));
    MIds = sum(Ids(:)); 
    Icds = Pcds.*log(Pcds./(Pcd*Ps));
    Icds(isnan(Icds)) = 0;
    MIcds = sum(Icds(:));

    Hs = -sum(Ps.*log(Ps));

    % Proficiencies calculated from Bootstrapping (BS)
    PROFcs_BS(i) = MIcs./Hs;
    PROFds_BS(i) = MIds./Hs;
    PROFcds_BS(i) = MIcds./Hs;
end

% Histograms of Bootstrapped Proficiencies

% figure;
% histogram(PROFcs_BS);
% hold on;
% histogram(PROFds_BS);
% histogram(PROFcds_BS);
% plot([PROFcs,PROFcs],[0,800],'k-');
% plot([PROFds,PROFds],[0,800],'k-');
% plot([PROFcds,PROFcds],[0,800],'k-');

% Construct 95% Confidence Intervals (CI) from Bootstrap Percentiles
PROFcs_CI = prctile(PROFcs_BS,[2.5,97.5]);
PROFds_CI = prctile(PROFds_BS,[2.5,97.5]);
PROFcds_CI = prctile(PROFcds_BS,[2.5,97.5]);




%% RESAMPLING UNIFORMLY FROM EDGE, MIDDLE, AND INTERIOR CELLS 

N = length(Ecells);
Nsample = round(N/3); % Randomly sampling N/3 edge, N/3 middle, and N/3 interior cells

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:3 % for edge, middle, interior cells
        icells = find(Dcells==j); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/3 cells from each
        n = [n;ni]; % list of all resampled cells
    end
    
    pcs = histcounts2(Ccells(n),Pcells(n)); 
    Pcs = pcs./sum(pcs(:)); 
    pds = histcounts2(Dcells(n),Pcells(n)); 
    Pds = pds./sum(pds(:));
    Pc = sum(Pcs,2);
    Pd = sum(Pds,2);
    Ps = sum(Pcs,1);

    pcds = histcounts2(CDcells(n),Pcells(n)); 
    Pcds = pcds./sum(pcds(:)); 
    Pcd = sum(Pcds,2); 

    Ics = Pcs.*log(Pcs./(Pc*Ps));
    MIcs = sum(Ics(:));
    Ids = Pds.*log(Pds./(Pd*Ps));
    MIds = sum(Ids(:));
    Icds = Pcds.*log(Pcds./(Pcd*Ps));
    Icds(isnan(Icds)) = 0;
    MIcds = sum(Icds(:));

    Hs = -sum(Ps.*log(Ps));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge (DS)
    PROFcs_DS_BS(i) = MIcs./Hs; 
    PROFds_DS_BS(i) = MIds./Hs;
    PROFcds_DS_BS(i) = MIcds./Hs;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dedge
PROFcs_DS = mean(PROFcs_DS_BS); 
PROFds_DS = mean(PROFds_DS_BS);
PROFcds_DS = mean(PROFcds_DS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcs_DS_CI = prctile(PROFcs_DS_BS,[2.5 97.5]);
PROFds_DS_CI = prctile(PROFds_DS_BS,[2.5 97.5]);
PROFcds_DS_CI = prctile(PROFcds_DS_BS,[2.5 97.5]);

PROFs_DS = [PROFcs_DS; PROFds_DS; PROFcds_DS];
PROFs_DS_CI = [PROFcs_DS_CI; PROFds_DS_CI; PROFcds_DS_CI];

F = figure;
set(gcf, 'Color', 'w');
F.Position(3) = F.Position(4)*1.61803398875;
B1 = bar(1,PROFcs_DS, 'LineWidth', 1); hold on;
B2 = bar(2,PROFds_DS, 'LineWidth', 1);
B3 = bar(3,PROFcds_DS, 'LineWidth', 1);
B1.FaceColor = [1 1 1];
B1.EdgeColor = [0 0 0];
B2.FaceColor = [0.7 0.7 0.7];
B2.EdgeColor = [0 0 0];
B3.FaceColor = [0.4 0.4 0.4];
B3.EdgeColor = [0 0 0];
er = errorbar([1:3],PROFs_DS,PROFs_DS-PROFs_DS_CI(:,1),PROFs_DS_CI(:,2)-PROFs_DS);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.7]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');


%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE

[~,~,Ccells] = histcounts(concC,linspace(0,1,10)); % Binning cells by Dsource into 9 linearly spaced bins (not by percentile)
uniqbin = unique(Ccells);  % bins with cells

N = length(Ccells);
Nsample = round(N/length(uniqbin)); % Sample N/9 cells from each Dsource bin

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 9 Dsource bins
        icells = find(Ccells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/9 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end
    
    pcs = histcounts2(Ccells(n),Pcells(n));
    Pcs = pcs./sum(pcs(:));
    pds = histcounts2(Dcells(n),Pcells(n)); 
    Pds = pds./sum(pds(:));
    Pc = sum(Pcs,2);
    Pd = sum(Pds,2);
    Ps = sum(Pcs,1);

    pcds = histcounts2(CDcells(n),Pcells(n)); 
    Pcds = pcds./sum(pcds(:)); 
    Pcd = sum(Pcds,2);

    Ics = Pcs.*log(Pcs./(Pc*Ps));
    MIcs = sum(Ics(:));
    Ids = Pds.*log(Pds./(Pd*Ps));
    MIds = sum(Ids(:));
    Icds = Pcds.*log(Pcds./(Pcd*Ps));
    Icds(isnan(Icds)) = 0;
    MIcds = sum(Icds(:));

    Hs = -sum(Ps.*log(Ps));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dsource (CS)
    PROFcs_CS_BS(i) = MIcs./Hs; 
    PROFds_CS_BS(i) = MIds./Hs;
    PROFcds_CS_BS(i) = MIcds./Hs;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dsource
PROFcs_CS = mean(PROFcs_CS_BS);
PROFds_CS = mean(PROFds_CS_BS);
PROFcds_CS = mean(PROFcds_CS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcs_CS_CI = prctile(PROFcs_CS_BS,[2.5 97.5]);
PROFds_CS_CI = prctile(PROFds_CS_BS,[2.5 97.5]);
PROFcds_CS_CI = prctile(PROFcds_CS_BS,[2.5 97.5]);

PROFs_CS = [PROFcs_CS; PROFds_CS; PROFcds_CS];
PROFs_CS_CI = [PROFcs_CS_CI; PROFds_CS_CI; PROFcds_CS_CI];


%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE AND DEDGE
% binning cells into 9 x 3 = 27 bins for Dsource and Dedge
% resampling uniformly from nonzero bins

CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource
uniqbin = unique(CDcells);  % Cells binned by Dsource and Dedge into 27 bins


N = length(CDcells);
Nsample = round(N/length(uniqbin));

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 27 bins
        icells = find(CDcells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/27 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end

    pcs = histcounts2(Ccells(n),Pcells(n));
    Pcs = pcs./sum(pcs(:));
    pds = histcounts2(Dcells(n),Pcells(n));
    Pds = pds./sum(pds(:));
    Pc = sum(Pcs,2);
    Pd = sum(Pds,2);
    Ps = sum(Pcs,1);

    pcds = histcounts2(CDcells(n),Pcells(n)); 
    Pcds = pcds./sum(pcds(:));
    Pcd = sum(Pcds,2);
    
    Ics = Pcs.*log(Pcs./(Pc*Ps));
    MIcs = sum(Ics(:));
    Ids = Pds.*log(Pds./(Pd*Ps));
    MIds = sum(Ids(:));
    Icds = Pcds.*log(Pcds./(Pcd*Ps));
    Icds(isnan(Icds)) = 0;
    MIcds = sum(Icds(:));

    Hs = -sum(Ps.*log(Ps));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge and Dsource (CDS)
    PROFcs_CDS_BS(i) = MIcs./Hs; 
    PROFds_CDS_BS(i) = MIds./Hs;
    PROFcds_CDS_BS(i) = MIcds./Hs;
end

PROFcs_CDS = mean(PROFcs_CDS_BS);
PROFds_CDS = mean(PROFds_CDS_BS);
PROFcds_CDS = mean(PROFcds_CDS_BS);

PROFcs_CDS_CI = prctile(PROFcs_CDS_BS,[2.5 97.5]);
PROFds_CDS_CI = prctile(PROFds_CDS_BS,[2.5 97.5]);
PROFcds_CDS_CI = prctile(PROFcds_CDS_BS,[2.5 97.5]);

PROFs_CDS = [PROFcs_CDS; PROFds_CDS; PROFcds_CDS];
PROFs_CDS_CI = [PROFcs_CDS_CI; PROFds_CDS_CI; PROFcds_CDS_CI];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% OCT4/SOX2 RATIO PROFICIENCY AT t = 0h %%

load('../Fig1bc/0hr/Fig1b_0hBins.mat');
Ccells = binC; %cells binned by Dsource (BMP concentration)into 6 bins
Ecells = ECcells; % edge cells 
Icells = ICcells; % interior cells 
Mcells = ~(ECcells|ICcells); % cells that are neither on edge nor interior
Dcells = Ecells + 2*Mcells + 3*Icells; % indexing cells by Dedge
[~,~,Rcells] = histcounts(ratioC,logspace(log10(0.5),log10(4),4)); % bin cells by log(OCT4/SOX2)
CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource

pcr = histcounts2(Ccells,Rcells); % 6x2 frequency bin of cells at different Dsource and OCT4/SOX2
Pcr = pcr./sum(pcr(:)); % frequency bin --> probability bin
pdr = histcounts2(Dcells,Rcells); % 3x2 frequency bin of cells at different Dedge and OCT4/SOX2
Pdr = pdr./sum(pdr(:)); % frequency bin --> probability bin
Pc = sum(Pcr,2); %marginal probability P(Dsource)
Pd = sum(Pdr,2); %marginal probability P(edge/middle/interior)
Pr = sum(Pcr,1); %marginal probability P(OCT4/SOX2)

pcdr = histcounts2(CDcells,Rcells); %18x2 frequency bin of cells at different Dsource and Dedge and OCT4/SOX2
Pcdr = pcdr./sum(pcdr(:)); % frequency bin --> probability bin
Pcd = sum(Pcdr,2); %18x1 marginal probability P(Dsource and Dedge)

Icr = Pcr.*log(Pcr./(Pc*Pr));
MIcr = sum(Icr(:)); % Mutual Information btwn Dsource and OCT4/SOX2
Idr = Pdr.*log(Pdr./(Pd*Pr));
MIdr = sum(Idr(:)); % Mutual Information btwn Dedge and OCT4/SOX2
Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
Icdr(isnan(Icdr)) = 0;
MIcdr = sum(Icdr(:)); % Mutual Information btwn (Dsource AND Dedge) and OCT4/SOX2

Hr = -sum(Pr.*log(Pr)); % Entropy of OCT4/SOX2

PROFcr0 = MIcr./Hr; % Proficiency btwn Dsource and OCT4/SOX2
PROFdr0 = MIdr./Hr; % Proficiency btwn Dedge and OCT4/SOX2
PROFcdr0 = MIcdr./Hr; % Proficiency btwn (Dsource AND Dedge) and OCT4/SOX2

%% BOOTSTRAPPING CONFIDENCE INTERVALS 

N = length(Ccells);

for i = 1:10000 % Resampling from data 10,000 times with replacement
    i
    Ni = ceil(rand(N,1).* N); % Same sample size N as original data 

    pcr = histcounts2(Ccells(Ni),Rcells(Ni)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(Ni),Rcells(Ni)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(Ni),Rcells(Ni));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Proficiencies calculated from Bootstrapping (BS)
    PROFcr0_BS(i) = MIcr./Hr;
    PROFdr0_BS(i) = MIdr./Hr;
    PROFcdr0_BS(i) = MIcdr./Hr;
end

% Construct 95% Confidence Intervals (CI) from Bootstrap Percentiles
PROFcr0_CI = prctile(PROFcr0_BS,[2.5,97.5]);
PROFdr0_CI = prctile(PROFdr0_BS,[2.5,97.5]);
PROFcdr0_CI = prctile(PROFcdr0_BS,[2.5,97.5]);

%% RESAMPLING UNIFORMLY FROM EDGE, MIDDLE, AND INTERIOR CELLS 

N = length(Ecells);
Nsample = round(N/3); % Randomly sampling N/3 edge, N/3 middle, and N/3 interior cells

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:3 % for edge, middle, interior cells
        icells = find(Dcells==j); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/3 cells from each
        n = [n;ni]; % list of all resampled cells
    end
    
    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge (DS)
    PROFcr0_DS_BS(i) = MIcr./Hr;
    PROFdr0_DS_BS(i) = MIdr./Hr;
    PROFcdr0_DS_BS(i) = MIcdr./Hr;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dedge
PROFcr0_DS = mean(PROFcr0_DS_BS); 
PROFdr0_DS = mean(PROFdr0_DS_BS);
PROFcdr0_DS = mean(PROFcdr0_DS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcr0_DS_CI = prctile(PROFcr0_DS_BS,[2.5 97.5]);
PROFdr0_DS_CI = prctile(PROFdr0_DS_BS,[2.5 97.5]);
PROFcdr0_DS_CI = prctile(PROFcdr0_DS_BS,[2.5 97.5]);

%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE

[~,~,Ccells] = histcounts(concC,linspace(0,1,10)); % Binning cells by Dsource into 9 linearly spaced bins (not by percentile)
uniqbin = unique(Ccells);  % bins with cells

N = length(Ccells);
Nsample = round(N/length(uniqbin)); % Sample N/9 cells from each Dsource bin

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 9 Dsource bins
        icells = find(Ccells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/9 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end
    
    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dsource (CS)
    PROFcr0_CS_BS(i) = MIcr./Hr; 
    PROFdr0_CS_BS(i) = MIdr./Hr;
    PROFcdr0_CS_BS(i) = MIcdr./Hr;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dsource
PROFcr0_CS = mean(PROFcr0_CS_BS);
PROFdr0_CS = mean(PROFdr0_CS_BS);
PROFcdr0_CS = mean(PROFcdr0_CS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcr0_CS_CI = prctile(PROFcr0_CS_BS,[2.5 97.5]);
PROFdr0_CS_CI = prctile(PROFdr0_CS_BS,[2.5 97.5]);
PROFcdr0_CS_CI = prctile(PROFcdr0_CS_BS,[2.5 97.5]);


%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE AND DEDGE
% binning cells into 9 x 3 = 27 bins for Dsource and Dedge
% resampling uniformly from nonzero bins

CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource
uniqbin = unique(CDcells);  % Cells binned by Dsource and Dedge into 18 bins

N = length(CDcells);
Nsample = round(N/length(uniqbin));

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 27 bins
        icells = find(CDcells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/27 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end

    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge and Dsource (CDS)
    PROFcr0_CDS_BS(i) = MIcr./Hr; 
    PROFdr0_CDS_BS(i) = MIdr./Hr;
    PROFcdr0_CDS_BS(i) = MIcdr./Hr;
end

PROFcr0_CDS = mean(PROFcr0_CDS_BS);
PROFdr0_CDS = mean(PROFdr0_CDS_BS);
PROFcdr0_CDS = mean(PROFcdr0_CDS_BS);

PROFcr0_CDS_CI = prctile(PROFcr0_CDS_BS,[2.5 97.5]);
PROFdr0_CDS_CI = prctile(PROFdr0_CDS_BS,[2.5 97.5]);
PROFcdr0_CDS_CI = prctile(PROFcdr0_CDS_BS,[2.5 97.5]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% OCT4/SOX2 RATIO PROFICIENCY AT t = 10h %%

load('../Fig1bc/10hr/Fig1b_10hBins.mat');
Ccells = binC; %cells binned by Dsource (BMP concentration)into 6 bins
Ecells = ECcells; % edge cells 
Icells = ICcells; % interior cells 
Mcells = ~(ECcells|ICcells); % cells that are neither on edge nor interior
Dcells = Ecells + 2*Mcells + 3*Icells; % indexing cells by Dedge
[~,~,Rcells] = histcounts(ratioC,logspace(log10(0.5),log10(4),4)); % bin cells by log(OCT4/SOX2)
CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource

pcr = histcounts2(Ccells,Rcells); % 6x2 frequency bin of cells at different Dsource and OCT4/SOX2
Pcr = pcr./sum(pcr(:)); % frequency bin --> probability bin
pdr = histcounts2(Dcells,Rcells); % 3x2 frequency bin of cells at different Dedge and OCT4/SOX2
Pdr = pdr./sum(pdr(:)); % frequency bin --> probability bin
Pc = sum(Pcr,2); %marginal probability P(Dsource)
Pd = sum(Pdr,2); %marginal probability P(edge/middle/interior)
Pr = sum(Pcr,1); %marginal probability P(OCT4/SOX2)

pcdr = histcounts2(CDcells,Rcells); %18x2 frequency bin of cells at different Dsource and Dedge and OCT4/SOX2
Pcdr = pcdr./sum(pcdr(:)); % frequency bin --> probability bin
Pcd = sum(Pcdr,2); %18x1 marginal probability P(Dsource and Dedge)

Icr = Pcr.*log(Pcr./(Pc*Pr));
Icr(isnan(Icr))=0;
MIcr = sum(Icr(:)); % Mutual Information btwn Dsource and OCT4/SOX2
Idr = Pdr.*log(Pdr./(Pd*Pr));
Idr(isnan(Idr))=0;
MIdr = sum(Idr(:)); % Mutual Information btwn Dedge and OCT4/SOX2
Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
Icdr(isnan(Icdr)) = 0;
MIcdr = sum(Icdr(:)); % Mutual Information btwn (Dsource AND Dedge) and OCT4/SOX2

Hr = -sum(Pr.*log(Pr)); % Entropy of OCT4/SOX2

PROFcr10 = MIcr./Hr; % Proficiency btwn Dsource and OCT4/SOX2
PROFdr10 = MIdr./Hr; % Proficiency btwn Dedge and OCT4/SOX2
PROFcdr10 = MIcdr./Hr; % Proficiency btwn (Dsource AND Dedge) and OCT4/SOX2

%% BOOTSTRAPPING CONFIDENCE INTERVALS 

N = length(Ccells);

for i = 1:10000 % Resampling from data 10,000 times with replacement
    i
    Ni = ceil(rand(N,1).* N); % Same sample size N as original data 

    pcr = histcounts2(Ccells(Ni),Rcells(Ni)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(Ni),Rcells(Ni)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(Ni),Rcells(Ni));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Proficiencies calculated from Bootstrapping (BS)
    PROFcr10_BS(i) = MIcr./Hr;
    PROFdr10_BS(i) = MIdr./Hr;
    PROFcdr10_BS(i) = MIcdr./Hr;
end

% Construct 95% Confidence Intervals (CI) from Bootstrap Percentiles
PROFcr10_CI = prctile(PROFcr10_BS,[2.5,97.5]);
PROFdr10_CI = prctile(PROFdr10_BS,[2.5,97.5]);
PROFcdr10_CI = prctile(PROFcdr10_BS,[2.5,97.5]);

%% RESAMPLING UNIFORMLY FROM EDGE, MIDDLE, AND INTERIOR CELLS 

N = length(Ecells);
Nsample = round(N/3); % Randomly sampling N/3 edge, N/3 middle, and N/3 interior cells

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:3 % for edge, middle, interior cells
        icells = find(Dcells==j); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/3 cells from each
        n = [n;ni]; % list of all resampled cells
    end
    
    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge (DS)
    PROFcr10_DS_BS(i) = MIcr./Hr;
    PROFdr10_DS_BS(i) = MIdr./Hr;
    PROFcdr10_DS_BS(i) = MIcdr./Hr;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dedge
PROFcr10_DS = mean(PROFcr10_DS_BS); 
PROFdr10_DS = mean(PROFdr10_DS_BS);
PROFcdr10_DS = mean(PROFcdr10_DS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcr10_DS_CI = prctile(PROFcr10_DS_BS,[2.5 97.5]);
PROFdr10_DS_CI = prctile(PROFdr10_DS_BS,[2.5 97.5]);
PROFcdr10_DS_CI = prctile(PROFcdr10_DS_BS,[2.5 97.5]);

%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE

[~,~,Ccells] = histcounts(concC,linspace(0,1,10)); % Binning cells by Dsource into 9 linearly spaced bins (not by percentile)
uniqbin = unique(Ccells);  % Cells binned by Dsource into 9 bins

N = length(Ccells);
Nsample = round(N/length(uniqbin)); % Sample N/9 cells from each Dsource bin

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 9 Dsource bins
        icells = find(Ccells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/9 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end
    
    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dsource (CS)
    PROFcr10_CS_BS(i) = MIcr./Hr; 
    PROFdr10_CS_BS(i) = MIdr./Hr;
    PROFcdr10_CS_BS(i) = MIcdr./Hr;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dsource
PROFcr10_CS = mean(PROFcr10_CS_BS);
PROFdr10_CS = mean(PROFdr10_CS_BS);
PROFcdr10_CS = mean(PROFcdr10_CS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcr10_CS_CI = prctile(PROFcr10_CS_BS,[2.5 97.5]);
PROFdr10_CS_CI = prctile(PROFdr10_CS_BS,[2.5 97.5]);
PROFcdr10_CS_CI = prctile(PROFcdr10_CS_BS,[2.5 97.5]);


%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE AND DEDGE
% binning cells into 9 x 3 = 27 bins for Dsource and Dedge
% resampling uniformly from nonzero bins

CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource
uniqbin = unique(CDcells);  % Cells binned by Dsource and Dedge into 18 bins

N = length(CDcells);
Nsample = round(N/length(uniqbin));

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 27 bins
        icells = find(CDcells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/27 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end

    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge and Dsource (CDS)
    PROFcr10_CDS_BS(i) = MIcr./Hr; 
    PROFdr10_CDS_BS(i) = MIdr./Hr;
    PROFcdr10_CDS_BS(i) = MIcdr./Hr;
end

PROFcr10_CDS = mean(PROFcr10_CDS_BS);
PROFdr10_CDS = mean(PROFdr10_CDS_BS);
PROFcdr10_CDS = mean(PROFcdr10_CDS_BS);

PROFcr10_CDS_CI = prctile(PROFcr10_CDS_BS,[2.5 97.5]);
PROFdr10_CDS_CI = prctile(PROFdr10_CDS_BS,[2.5 97.5]);
PROFcdr10_CDS_CI = prctile(PROFcdr10_CDS_BS,[2.5 97.5]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% OCT4/SOX2 RATIO PROFICIENCY AT t = 18h %%

load('../Fig1bc/18hr/Fig1b_18hBins.mat');
Ccells = binC; %cells binned by Dsource (BMP concentration)into 6 bins
Ecells = ECcells; % edge cells 
Icells = ICcells; % interior cells 
Mcells = ~(ECcells|ICcells); % cells that are neither on edge nor interior
Dcells = Ecells + 2*Mcells + 3*Icells; % indexing cells by Dedge
[~,~,Rcells] = histcounts(ratioC,logspace(log10(0.5),log10(4),4)); % bin cells by log(OCT4/SOX2)
CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource

pcr = histcounts2(Ccells,Rcells); % 6x2 frequency bin of cells at different Dsource and OCT4/SOX2
Pcr = pcr./sum(pcr(:)); % frequency bin --> probability bin
pdr = histcounts2(Dcells,Rcells); % 3x2 frequency bin of cells at different Dedge and OCT4/SOX2
Pdr = pdr./sum(pdr(:)); % frequency bin --> probability bin
Pc = sum(Pcr,2); %marginal probability P(Dsource)
Pd = sum(Pdr,2); %marginal probability P(edge/middle/interior)
Pr = sum(Pcr,1); %marginal probability P(OCT4/SOX2)

pcdr = histcounts2(CDcells,Rcells); %18x2 frequency bin of cells at different Dsource and Dedge and OCT4/SOX2
Pcdr = pcdr./sum(pcdr(:)); % frequency bin --> probability bin
Pcd = sum(Pcdr,2); %18x1 marginal probability P(Dsource and Dedge)

Icr = Pcr.*log(Pcr./(Pc*Pr));
Icr(isnan(Icr))=0;
MIcr = sum(Icr(:)); % Mutual Information btwn Dsource and OCT4/SOX2
Idr = Pdr.*log(Pdr./(Pd*Pr));
Idr(isnan(Idr))=0;
MIdr = sum(Idr(:)); % Mutual Information btwn Dedge and OCT4/SOX2
Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
Icdr(isnan(Icdr)) = 0;
MIcdr = sum(Icdr(:)); % Mutual Information btwn (Dsource AND Dedge) and OCT4/SOX2

Hr = -sum(Pr.*log(Pr)); % Entropy of OCT4/SOX2

PROFcr18 = MIcr./Hr; % Proficiency btwn Dsource and OCT4/SOX2
PROFdr18 = MIdr./Hr; % Proficiency btwn Dedge and OCT4/SOX2
PROFcdr18 = MIcdr./Hr; % Proficiency btwn (Dsource AND Dedge) and OCT4/SOX2

%% BOOTSTRAPPING CONFIDENCE INTERVALS 

N = length(Ccells);

for i = 1:10000 % Resampling from data 10,000 times with replacement
    i
    Ni = ceil(rand(N,1).* N); % Same sample size N as original data 

    pcr = histcounts2(Ccells(Ni),Rcells(Ni)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(Ni),Rcells(Ni)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(Ni),Rcells(Ni));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Proficiencies calculated from Bootstrapping (BS)
    PROFcr18_BS(i) = MIcr./Hr;
    PROFdr18_BS(i) = MIdr./Hr;
    PROFcdr18_BS(i) = MIcdr./Hr;
end

% Construct 95% Confidence Intervals (CI) from Bootstrap Percentiles
PROFcr18_CI = prctile(PROFcr18_BS,[2.5,97.5]);
PROFdr18_CI = prctile(PROFdr18_BS,[2.5,97.5]);
PROFcdr18_CI = prctile(PROFcdr18_BS,[2.5,97.5]);

%% RESAMPLING UNIFORMLY FROM EDGE, MIDDLE, AND INTERIOR CELLS 

N = length(Ecells);
Nsample = round(N/3); % Randomly sampling N/3 edge, N/3 middle, and N/3 interior cells

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:3 % for edge, middle, interior cells
        icells = find(Dcells==j); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/3 cells from each
        n = [n;ni]; % list of all resampled cells
    end
    
    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge (DS)
    PROFcr18_DS_BS(i) = MIcr./Hr;
    PROFdr18_DS_BS(i) = MIdr./Hr;
    PROFcdr18_DS_BS(i) = MIcdr./Hr;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dedge
PROFcr18_DS = mean(PROFcr18_DS_BS); 
PROFdr18_DS = mean(PROFdr18_DS_BS);
PROFcdr18_DS = mean(PROFcdr18_DS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcr18_DS_CI = prctile(PROFcr18_DS_BS,[2.5 97.5]);
PROFdr18_DS_CI = prctile(PROFdr18_DS_BS,[2.5 97.5]);
PROFcdr18_DS_CI = prctile(PROFcdr18_DS_BS,[2.5 97.5]);

%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE

[~,~,Ccells] = histcounts(concC,linspace(0,1,10)); % Binning cells by Dsource into 9 linearly spaced bins (not by percentile)
uniqbin = unique(Ccells);  % Cells binned by Dsource into 9 bins

N = length(Ccells);
Nsample = round(N/length(uniqbin)); % Sample N/9 cells from each Dsource bin

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 9 Dsource bins
        icells = find(Ccells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/9 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end
    
    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dsource (CS)
    PROFcr18_CS_BS(i) = MIcr./Hr; 
    PROFdr18_CS_BS(i) = MIdr./Hr;
    PROFcdr18_CS_BS(i) = MIcdr./Hr;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dsource
PROFcr18_CS = mean(PROFcr18_CS_BS);
PROFdr18_CS = mean(PROFdr18_CS_BS);
PROFcdr18_CS = mean(PROFcdr18_CS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFcr18_CS_CI = prctile(PROFcr18_CS_BS,[2.5 97.5]);
PROFdr18_CS_CI = prctile(PROFdr18_CS_BS,[2.5 97.5]);
PROFcdr18_CS_CI = prctile(PROFcdr18_CS_BS,[2.5 97.5]);


%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE AND DEDGE
% binning cells into 9 x 3 = 27 bins for Dsource and Dedge
% resampling uniformly from nonzero bins

CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource
uniqbin = unique(CDcells);  % Cells binned by Dsource and Dedge into 27 bins

N = length(CDcells);
Nsample = round(N/length(uniqbin));

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 27 bins
        icells = find(CDcells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/27 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end

    pcr = histcounts2(Ccells(n),Rcells(n)); 
    Pcr = pcr./sum(pcr(:)); 
    pdr = histcounts2(Dcells(n),Rcells(n)); 
    Pdr = pdr./sum(pdr(:)); 
    Pc = sum(Pcr,2); 
    Pd = sum(Pdr,2); 
    Pr = sum(Pcr,1); 

    pcdr = histcounts2(CDcells(n),Rcells(n));  
    Pcdr = pcdr./sum(pcdr(:)); 
    Pcd = sum(Pcdr,2); 

    Icr = Pcr.*log(Pcr./(Pc*Pr));
    Icr(isnan(Icr))=0;
    MIcr = sum(Icr(:)); 
    Idr = Pdr.*log(Pdr./(Pd*Pr));
    Idr(isnan(Idr))=0;
    MIdr = sum(Idr(:)); 
    Icdr = Pcdr.*log(Pcdr./(Pcd*Pr));
    Icdr(isnan(Icdr)) = 0;
    MIcdr = sum(Icdr(:));

    Hr = -sum(Pr.*log(Pr));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge and Dsource (CDS)
    PROFcr18_CDS_BS(i) = MIcr./Hr; 
    PROFdr18_CDS_BS(i) = MIdr./Hr;
    PROFcdr18_CDS_BS(i) = MIcdr./Hr;
end

PROFcr18_CDS = mean(PROFcr18_CDS_BS);
PROFdr18_CDS = mean(PROFdr18_CDS_BS);
PROFcdr18_CDS = mean(PROFcdr18_CDS_BS);

PROFcr18_CDS_CI = prctile(PROFcr18_CDS_BS,[2.5 97.5]);
PROFdr18_CDS_CI = prctile(PROFdr18_CDS_BS,[2.5 97.5]);
PROFcdr18_CDS_CI = prctile(PROFcdr18_CDS_BS,[2.5 97.5]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%% BRACHYURY (T) PROFICIENCY AT t = 18h %%

load('../Fig1bc/Immunostain/Fig1b_ImmBins.mat');
Ccells = binC; % 6 bins for Dsource
Ecells = ECcells;
Icells = ICcells;
Mcells = ~(ECcells|ICcells);
Dcells = Ecells + 2*Mcells + 3*Icells;
Tcells = TCcells;
CDcells = Dcells+3*Ccells;

pct = histcounts2(Ccells,Tcells); % 6x2 frequency bin of cells at different Dsource and T
Pct = pct./sum(pct(:));
pdt = histcounts2(Dcells,Tcells); % 3x2 frequency bin of cells at different Dedge and T
Pdt = pdt./sum(pdt(:));
Pc = sum(Pct,2); 
Pd = sum(Pdt,2);
Pt = sum(Pct,1); %marginal probability P(T)

pcdt = histcounts2(CDcells,Tcells); %18x2 frequency bin of cells at different Dsource and Dedge and T
Pcdt = pcdt./sum(pcdt(:)); 
Pcd = sum(Pcdt,2); %18x1 marginal probability P(Dsource and Dedge)

Ict = Pct.*log(Pct./(Pc*Pt));
Ict(isnan(Ict)) = 0;
MIct = sum(Ict(:)); % Mutual Information btwn Dsource and T
Idt = Pdt.*log(Pdt./(Pd*Pt));
Idt(isnan(Idt)) = 0;
MIdt = sum(Idt(:)); % Mutual Information btwn Dedge and T
Icdt = Pcdt.*log(Pcdt./(Pcd*Pt));
Icdt(isnan(Icdt)) = 0;
MIcdt = sum(Icdt(:)); % Mutual Information btwn (Dsource AND Dedge) and T

Ht = -sum(Pt.*log(Pt)); % Entropy of T

PROFct = MIct./Ht; % Proficiency btwn Dsource and T
PROFdt = MIdt./Ht; % Proficiency btwn Dedge and T
PROFcdt = MIcdt./Ht; % Proficiency btwn (Dsource AND Dedge) and T

%% BOOTSTRAPPING CONFIDENCE INTERVALS 

N = length(Ccells);

for i = 1:10000 % Resampling from data 10,000 times with replacement
    i
    Ni = ceil(rand(N,1).* N); % Same sample size N as original data 

    pct = histcounts2(Ccells(Ni),Tcells(Ni)); 
    Pct = pct./sum(pct(:)); 
    pdt = histcounts2(Dcells(Ni),Tcells(Ni)); 
    Pdt = pdt./sum(pdt(:)); 
    Pc = sum(Pct,2); 
    Pd = sum(Pdt,2); 
    Pt = sum(Pct,1); 

    pcdt = histcounts2(CDcells(Ni),Tcells(Ni));  
    Pcdt = pcdt./sum(pcdt(:)); 
    Pcd = sum(Pcdt,2); 

    Ict = Pct.*log(Pct./(Pc*Pt));
    Ict(isnan(Ict)) = 0;
    MIct = sum(Ict(:)); 
    Idt = Pdt.*log(Pdt./(Pd*Pt));
    Idt(isnan(Idt)) = 0;
    MIdt = sum(Idt(:));
    Icdt = Pcdt.*log(Pcdt./(Pcd*Pt));
    Icdt(isnan(Icdt)) = 0;
    MIcdt = sum(Icdt(:));

    Ht = -sum(Pt.*log(Pt));

    % Proficiencies calculated from Bootstrapping (BS)
    PROFct_BS(i) = MIct./Ht;
    PROFdt_BS(i) = MIdt./Ht;
    PROFcdt_BS(i) = MIcdt./Ht;
end

% Construct 95% Confidence Intervals (CI) from Bootstrap Percentiles
PROFct_CI = prctile(PROFct_BS,[2.5,97.5]);
PROFdt_CI = prctile(PROFdt_BS,[2.5,97.5]);
PROFcdt_CI = prctile(PROFcdt_BS,[2.5,97.5]);

%% RESAMPLING UNIFORMLY FROM EDGE, MIDDLE, AND INTERIOR CELLS 

N = length(Ecells);
Nsample = round(N/3); % Randomly sampling N/3 edge, N/3 middle, and N/3 interior cells

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:3 % for edge, middle, interior cells
        icells = find(Dcells==j); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/3 cells from each
        n = [n;ni]; % list of all resampled cells
    end
    
    pct = histcounts2(Ccells(n),Tcells(n)); 
    Pct = pct./sum(pct(:)); 
    pdt = histcounts2(Dcells(n),Tcells(n)); 
    Pdt = pdt./sum(pdt(:)); 
    Pc = sum(Pct,2); 
    Pd = sum(Pdt,2); 
    Pt = sum(Pct,1); 

    pcdt = histcounts2(CDcells(n),Tcells(n));  
    Pcdt = pcdt./sum(pcdt(:)); 
    Pcd = sum(Pcdt,2); 

    Ict = Pct.*log(Pct./(Pc*Pt));
    Ict(isnan(Ict)) = 0;
    MIct = sum(Ict(:)); 
    Idt = Pdt.*log(Pdt./(Pd*Pt));
    Idt(isnan(Idt)) = 0;
    MIdt = sum(Idt(:));
    Icdt = Pcdt.*log(Pcdt./(Pcd*Pt));
    Icdt(isnan(Icdt)) = 0;
    MIcdt = sum(Icdt(:));

    Ht = -sum(Pt.*log(Pt));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge (DS)
    PROFct_DS_BS(i) = MIct./Ht;
    PROFdt_DS_BS(i) = MIdt./Ht;
    PROFcdt_DS_BS(i) = MIcdt./Ht;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dedge
PROFct_DS = mean(PROFct_DS_BS); 
PROFdt_DS = mean(PROFdt_DS_BS);
PROFcdt_DS = mean(PROFcdt_DS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFct_DS_CI = prctile(PROFct_DS_BS,[2.5 97.5]);
PROFdt_DS_CI = prctile(PROFdt_DS_BS,[2.5 97.5]);
PROFcdt_DS_CI = prctile(PROFcdt_DS_BS,[2.5 97.5]);

%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE

[~,~,Ccells] = histcounts(concC,linspace(0,1,10)); % Binning cells by Dsource into 9 linearly spaced bins (not by percentile)
uniqbin = unique(Ccells);  % Cells binned by Dsource into 9 bins

N = length(Ccells);
Nsample = round(N/length(uniqbin)); % Sample N/9 cells from each Dsource bin

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 9 Dsource bins
        icells = find(Ccells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/9 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end
    
    pct = histcounts2(Ccells(n),Tcells(n)); 
    Pct = pct./sum(pct(:)); 
    pdt = histcounts2(Dcells(n),Tcells(n)); 
    Pdt = pdt./sum(pdt(:)); 
    Pc = sum(Pct,2); 
    Pd = sum(Pdt,2); 
    Pt = sum(Pct,1); 

    pcdt = histcounts2(CDcells(n),Tcells(n));  
    Pcdt = pcdt./sum(pcdt(:)); 
    Pcd = sum(Pcdt,2); 

    Ict = Pct.*log(Pct./(Pc*Pt));
    Ict(isnan(Ict)) = 0;
    MIct = sum(Ict(:)); 
    Idt = Pdt.*log(Pdt./(Pd*Pt));
    Idt(isnan(Idt)) = 0;
    MIdt = sum(Idt(:));
    Icdt = Pcdt.*log(Pcdt./(Pcd*Pt));
    Icdt(isnan(Icdt)) = 0;
    MIcdt = sum(Icdt(:));

    Ht = -sum(Pt.*log(Pt));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dsource (CS)
    PROFct_CS_BS(i) = MIct./Ht; 
    PROFdt_CS_BS(i) = MIdt./Ht;
    PROFcdt_CS_BS(i) = MIcdt./Ht;
end

% Bootstrap Estimate of Proficiency -- sampling uniformly from Dsource
PROFct_CS = mean(PROFct_CS_BS);
PROFdt_CS = mean(PROFdt_CS_BS);
PROFcdt_CS = mean(PROFcdt_CS_BS);

% 95% Confidence Intervals from Bootstrap Percentiles
PROFct_CS_CI = prctile(PROFct_CS_BS,[2.5 97.5]);
PROFdt_CS_CI = prctile(PROFdt_CS_BS,[2.5 97.5]);
PROFcdt_CS_CI = prctile(PROFcdt_CS_BS,[2.5 97.5]);


%% RESAMPLING CELLS UNIFORMLY FROM DIFFERENT DSOURCE AND DEDGE
% binning cells into 6 x 3 = 18 bins for Dsource and Dedge
% resampling uniformly from nonzero bins

CDcells = Dcells+3*Ccells;
uniqbin = unique(CDcells);  % Cells binned by Dsource and Dedge into 18 bins

N = length(CDcells);
Nsample = round(N/length(uniqbin));

for i = 1:10000 % Resampling 10,000 times with replacement
    i
    n = [];
    for j = 1:length(uniqbin) % for all 18 bins
        icells = find(CDcells==uniqbin(j)); % get cell indices
        Ni = length(icells);
        ni = icells(ceil(rand(Nsample,1)*Ni)); % sample N/18 cells from each bin
        n = [n;ni]; % list of all resampled cells
    end

    pct = histcounts2(Ccells(n),Tcells(n)); 
    Pct = pct./sum(pct(:)); 
    pdt = histcounts2(Dcells(n),Tcells(n)); 
    Pdt = pdt./sum(pdt(:)); 
    Pc = sum(Pct,2); 
    Pd = sum(Pdt,2); 
    Pt = sum(Pct,1); 

    pcdt = histcounts2(CDcells(n),Tcells(n));  
    Pcdt = pcdt./sum(pcdt(:)); 
    Pcd = sum(Pcdt,2); 

    Ict = Pct.*log(Pct./(Pc*Pt));
    Ict(isnan(Ict)) = 0;
    MIct = sum(Ict(:)); 
    Idt = Pdt.*log(Pdt./(Pd*Pt));
    Idt(isnan(Idt)) = 0;
    MIdt = sum(Idt(:));
    Icdt = Pcdt.*log(Pcdt./(Pcd*Pt));
    Icdt(isnan(Icdt)) = 0;
    MIcdt = sum(Icdt(:));

    Ht = -sum(Pt.*log(Pt));

    % Bootstrapped (BS) Proficiencies -- sampling uniformly from Dedge and Dsource (CDS)
    PROFct_CDS_BS(i) = MIct./Ht; 
    PROFdt_CDS_BS(i) = MIdt./Ht;
    PROFcdt_CDS_BS(i) = MIcdt./Ht;
end

PROFct_CDS = mean(PROFct_CDS_BS);
PROFdt_CDS = mean(PROFdt_CDS_BS);
PROFcdt_CDS = mean(PROFcdt_CDS_BS);

PROFct_CDS_CI = prctile(PROFct_CDS_BS,[2.5 97.5]);
PROFdt_CDS_CI = prctile(PROFdt_CDS_BS,[2.5 97.5]);
PROFcdt_CDS_CI = prctile(PROFcdt_CDS_BS,[2.5 97.5]);

save Fig1e.mat;

load Fig1e.mat;










%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% PLOTTING pSMAD1/5 PROFICIENCY

F = figure;
set(gcf, 'Color', 'w');
F.Position(3) = F.Position(4)*1.61803398875;
hold on;
myviolinbs(PROFcs,PROFcs_BS,1,[1 1 1])
myviolinbs(PROFds,PROFds_BS,2,[0.7 0.7 0.7])
myviolinbs(PROFcds,PROFcds_BS,3,[0.4 0.4 0.4])
xlim([0 4]);
ylim([0 0.7]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');
print('PROF_pSMAD','-dpdf');


PROFs = [PROFcs; PROFds; PROFcds];
PROFs_CI = [PROFcs_CI; PROFds_CI; PROFcds_CI];

F = figure;
set(gcf, 'Color', 'w');
F.Position(3) = F.Position(4)*1.61803398875;
hold on;
scatter(1+(rand(size(PROFcs_BS))-0.5).*0.8,PROFcs_BS,5,'filled','MarkerFaceColor',[0.8 0.8 0.8],'MarkerFaceAlpha',0.5)
scatter(2+(rand(size(PROFcs_BS))-0.5).*0.8,PROFds_BS,5,'filled','MarkerFaceColor',[0.6 0.6 0.6],'MarkerFaceAlpha',0.5)
scatter(3+(rand(size(PROFcs_BS))-0.5).*0.8,PROFcds_BS,5,'filled','MarkerFaceColor',[0.4 0.4 0.4],'MarkerFaceAlpha',0.5)
%B1 = bar(1,PROFcs, 'LineWidth', 1); 
% B2 = bar(2,PROFds, 'LineWidth', 1);
% B3 = bar(3,PROFcds, 'LineWidth', 1);
%B1.FaceColor = [1 1 1];
%B1.EdgeColor = [0 0 0];
% B2.FaceColor = [0.7 0.7 0.7];
% B2.EdgeColor = [0 0 0];
% B3.FaceColor = [0.4 0.4 0.4];
% B3.EdgeColor = [0 0 0];
er = errorbar(1:3,PROFs,PROFs-PROFs_CI(:,1),PROFs_CI(:,2)-PROFs);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.7]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');

%export_fig PROF_pSMAD.pdf;

%%

F = figure;
set(gcf, 'Color', 'w');
hold on;
myviolinbs(PROFcs_DS,PROFcs_DS_BS,1,[1 1 1])
myviolinbs(PROFds_DS,PROFds_DS_BS,2,[0.7 0.7 0.7])
myviolinbs(PROFcds_DS,PROFcds_DS_BS,3,[0.4 0.4 0.4])
xlim([0 4]);
ylim([0 0.6]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');
print('PROF_pSMAD_DS','-dpdf');

PROFs_DS = [PROFcs_DS; PROFds_DS; PROFcds_DS];
PROFs_DS_CI = [PROFcs_DS_CI; PROFds_DS_CI; PROFcds_DS_CI];

F = figure;
set(gcf, 'Color', 'w');
F.Position(3) = F.Position(4)*1.61803398875;
B1 = bar(1,PROFs_DS(1), 'LineWidth', 1); hold on;
B2 = bar(2,PROFs_DS(2), 'LineWidth', 1);
B3 = bar(3,PROFs_DS(3), 'LineWidth', 1);
B1.FaceColor = [1 1 1];
B1.EdgeColor = [0 0 0];
B2.FaceColor = [0.7 0.7 0.7];
B2.EdgeColor = [0 0 0];
B3.FaceColor = [0.4 0.4 0.4];
B3.EdgeColor = [0 0 0];
er = errorbar(1:3,PROFs_DS,PROFs_DS-PROFs_DS_CI(:,1),PROFs_DS_CI(:,2)-PROFs_DS);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.7]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');
export_fig PROF_pSMAD_DS.pdf;

%%
F = figure;
set(gcf, 'Color', 'w');
hold on;
myviolinbs(PROFcs_CS,PROFcs_CS_BS,1,[1 1 1])
myviolinbs(PROFds_CS,PROFds_CS_BS,2,[0.7 0.7 0.7])
myviolinbs(PROFcds_CS,PROFcds_CS_BS,3,[0.4 0.4 0.4])
xlim([0 4]);
ylim([0 0.6]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');
print('PROF_pSMAD_CS','-dpdf');

PROFs_CS = [PROFcs_CS; PROFds_CS; PROFcds_CS];
PROFs_CS_CI = [PROFcs_CS_CI; PROFds_CS_CI; PROFcds_CS_CI];

F = figure;
set(gcf, 'Color', 'w');
F.Position(3) = F.Position(4)*1.61803398875;
B1 = bar(1,PROFs_CS(1), 'LineWidth', 1); hold on;
B2 = bar(2,PROFs_CS(2), 'LineWidth', 1);
B3 = bar(3,PROFs_CS(3), 'LineWidth', 1);
B1.FaceColor = [1 1 1];
B1.EdgeColor = [0 0 0];
B2.FaceColor = [0.7 0.7 0.7];
B2.EdgeColor = [0 0 0];
B3.FaceColor = [0.4 0.4 0.4];
B3.EdgeColor = [0 0 0];
er = errorbar(1:3,PROFs_CS,PROFs_CS-PROFs_CS_CI(:,1),PROFs_CS_CI(:,2)-PROFs_CS);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.7]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');
export_fig PROF_pSMAD_CS.pdf;

%%

figure;
set(gcf, 'Color', 'w');
hold on;
myviolinbs(PROFcs_CDS,PROFcs_CDS_BS,1,[1 1 1])
myviolinbs(PROFds_CDS,PROFds_CDS_BS,2,[0.7 0.7 0.7])
myviolinbs(PROFcds_CDS,PROFcds_CDS_BS,3,[0.4 0.4 0.4])
xlim([0 4]);
ylim([0 0.6]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');
print('PROF_pSMAD_CDS','-dpdf');

PROFs_CDS = [PROFcs_CDS; PROFds_CDS; PROFcds_CDS];
PROFs_CDS_CI = [PROFcs_CDS_CI; PROFds_CDS_CI; PROFcds_CDS_CI];

F = figure;
set(gcf, 'Color', 'w');
F.Position(3) = F.Position(4)*1.61803398875;
B1 = bar(1,PROFs_CDS(1), 'LineWidth', 1); hold on;
B2 = bar(2,PROFs_CDS(2), 'LineWidth', 1);
B3 = bar(3,PROFs_CDS(3), 'LineWidth', 1);
B1.FaceColor = [1 1 1];
B1.EdgeColor = [0 0 0];
B2.FaceColor = [0.7 0.7 0.7];
B2.EdgeColor = [0 0 0];
B3.FaceColor = [0.4 0.4 0.4];
B3.EdgeColor = [0 0 0];
er = errorbar(1:3,PROFs_CDS,PROFs_CDS-PROFs_CDS_CI(:,1),PROFs_CDS_CI(:,2)-PROFs_CDS);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.7]);
set(gca,'YMinorTick','on');
set(gca,'XTick',[])
set(gca,'FontSize',26);
xlabel('pSMAD1/5');
ylabel('Proficiency (%)');
export_fig PROF_pSMAD_CDS.pdf;


%% PLOTTING OCT4/SOX2 & T PROFICIENCY

figure;
hold on;
myviolinbs(PROFcr0,PROFcr0_BS,1,[1 1 1]);
myviolinbs(PROFdr0,PROFdr0_BS,2,[0.7 0.7 0.7]);
myviolinbs(PROFcdr0,PROFcdr0_BS,3,[0.4 0.4 0.4]);

myviolinbs(PROFcr10,PROFcr10_BS,5,[1 1 1]);
myviolinbs(PROFdr10,PROFdr10_BS,6,[0.7 0.7 0.7]);
myviolinbs(PROFcdr10,PROFcdr10_BS,7,[0.4 0.4 0.4]);

myviolinbs(PROFcr18,PROFcr18_BS,9,[1 1 1]);
myviolinbs(PROFdr18,PROFdr18_BS,10,[0.7 0.7 0.7]);
myviolinbs(PROFcdr18,PROFcdr18_BS,11,[0.4 0.4 0.4]);

myviolinbs(PROFct,PROFct_BS,13,[1 1 1]);
myviolinbs(PROFdt,PROFdt_BS,14,[0.7 0.7 0.7]);
myviolinbs(PROFcdt,PROFcdt_BS,15,[0.4 0.4 0.4]);
ylim([0 inf]);
ylim([0 0.45]);
print('PROF_OST','-dpdf');

PROFrt = [PROFcr0 PROFdr0 PROFcdr0; PROFcr10 PROFdr10 PROFcdr10; PROFcr18 PROFdr18 PROFcdr18; PROFct PROFdt PROFcdt];
PROFrt2 = PROFrt';
PROFrt2 = PROFrt2(:);
PROFrt_CI = [PROFcr0_CI; PROFdr0_CI; PROFcdr0_CI; PROFcr10_CI; PROFdr10_CI; PROFcdr10_CI; PROFcr18_CI; PROFdr18_CI; PROFcdr18_CI; PROFct_CI; PROFdt_CI; PROFcdt_CI];

F4 = figure;
F4.Position(3) = F4.Position(4)*1.61803398875;
set(gcf, 'Color', 'w');
B = bar(PROFrt, 'LineWidth', 1); hold on;
B(1).FaceColor = [1 1 1];
B(1).EdgeColor = [0 0 0];
B(2).FaceColor = [0.7 0.7 0.7];
B(2).EdgeColor = [0 0 0];
B(3).FaceColor = [0.4 0.4 0.4];
B(3).EdgeColor = [0 0 0];
set(gca,'XTickLabel',{'0h', '10h','18h','BRACHYURY'});
set(gca,'FontSize',26);
er = errorbar([0.78 1 1.22 1.78 2 2.22 2.78 3 3.22 3.78 4 4.22],PROFrt2,PROFrt2-PROFrt_CI(:,1),PROFrt_CI(:,2)-PROFrt2);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.4]);
set(gca,'YMinorTick','on');
xlabel('OCT4/SOX2 Ratio');
ylabel('Proficiency (%)');
%export_fig PROF_OST.pdf;

%%
figure;
hold on;
myviolinbs(PROFcr0_DS,PROFcr0_DS_BS,1,[1 1 1]);
myviolinbs(PROFdr0_DS,PROFdr0_DS_BS,2,[0.7 0.7 0.7]);
myviolinbs(PROFcdr0_DS,PROFcdr0_DS_BS,3,[0.4 0.4 0.4]);

myviolinbs(PROFcr10_DS,PROFcr10_DS_BS,5,[1 1 1]);
myviolinbs(PROFdr10_DS,PROFdr10_DS_BS,6,[0.7 0.7 0.7]);
myviolinbs(PROFcdr10_DS,PROFcdr10_DS_BS,7,[0.4 0.4 0.4]);

myviolinbs(PROFcr18_DS,PROFcr18_DS_BS,9,[1 1 1]);
myviolinbs(PROFdr18_DS,PROFdr18_DS_BS,10,[0.7 0.7 0.7]);
myviolinbs(PROFcdr18_DS,PROFcdr18_DS_BS,11,[0.4 0.4 0.4]);

myviolinbs(PROFct_DS,PROFct_DS_BS,13,[1 1 1]);
myviolinbs(PROFdt_DS,PROFdt_DS_BS,14,[0.7 0.7 0.7]);
myviolinbs(PROFcdt_DS,PROFcdt_DS_BS,15,[0.4 0.4 0.4]);
ylim([0 inf]);
ylim([0 0.45]);
print('PROF_OST_DS','-dpdf');

PROFrt_DS = [PROFcr0_DS PROFdr0_DS PROFcdr0_DS; PROFcr10_DS PROFdr10_DS PROFcdr10_DS; PROFcr18_DS PROFdr18_DS PROFcdr18_DS; PROFct_DS PROFdt_DS PROFcdt_DS];
PROFrt2_DS = PROFrt_DS';
PROFrt2_DS = PROFrt2_DS(:);
PROFrt_DS_CI = [PROFcr0_DS_CI; PROFdr0_DS_CI; PROFcdr0_DS_CI; PROFcr10_DS_CI; PROFdr10_DS_CI; PROFcdr10_DS_CI; PROFcr18_DS_CI; PROFdr18_DS_CI; PROFcdr18_DS_CI; PROFct_DS_CI; PROFdt_DS_CI; PROFcdt_DS_CI];

F4 = figure;
F4.Position(3) = F4.Position(4)*1.61803398875;
set(gcf, 'Color', 'w');
B = bar(PROFrt_DS, 'LineWidth', 1); hold on;
B(1).FaceColor = [1 1 1];
B(1).EdgeColor = [0 0 0];
B(2).FaceColor = [0.7 0.7 0.7];
B(2).EdgeColor = [0 0 0];
B(3).FaceColor = [0.4 0.4 0.4];
B(3).EdgeColor = [0 0 0];
set(gca,'XTickLabel',{'0h', '10h','18h','BRACHYURY'});
set(gca,'FontSize',26);
er = errorbar([0.78 1 1.22 1.78 2 2.22 2.78 3 3.22 3.78 4 4.22],PROFrt2_DS,PROFrt2_DS-PROFrt_DS_CI(:,1),PROFrt_DS_CI(:,2)-PROFrt2_DS);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.4]);
set(gca,'YMinorTick','on');
xlabel('OCT4/SOX2 Ratio');
ylabel('Proficiency (%)');
export_fig PROF_OST_DS.pdf;

%%
figure;
hold on;
myviolinbs(PROFcr0_CS,PROFcr0_CS_BS,1,[1 1 1]);
myviolinbs(PROFdr0_CS,PROFdr0_CS_BS,2,[0.7 0.7 0.7]);
myviolinbs(PROFcdr0_CS,PROFcdr0_CS_BS,3,[0.4 0.4 0.4]);

myviolinbs(PROFcr10_CS,PROFcr10_CS_BS,5,[1 1 1]);
myviolinbs(PROFdr10_CS,PROFdr10_CS_BS,6,[0.7 0.7 0.7]);
myviolinbs(PROFcdr10_CS,PROFcdr10_CS_BS,7,[0.4 0.4 0.4]);

myviolinbs(PROFcr18_CS,PROFcr18_CS_BS,9,[1 1 1]);
myviolinbs(PROFdr18_CS,PROFdr18_CS_BS,10,[0.7 0.7 0.7]);
myviolinbs(PROFcdr18_CS,PROFcdr18_CS_BS,11,[0.4 0.4 0.4]);

myviolinbs(PROFct_CS,PROFct_CS_BS,13,[1 1 1]);
myviolinbs(PROFdt_CS,PROFdt_CS_BS,14,[0.7 0.7 0.7]);
myviolinbs(PROFcdt_CS,PROFcdt_CS_BS,15,[0.4 0.4 0.4]);
ylim([0 inf]);
ylim([0 0.55]);
print('PROF_OST_CS','-dpdf');

PROFrt_CS = [PROFcr0_CS PROFdr0_CS PROFcdr0_CS; PROFcr10_CS PROFdr10_CS PROFcdr10_CS; PROFcr18_CS PROFdr18_CS PROFcdr18_CS; PROFct_CS PROFdt_CS PROFcdt_CS];
PROFrt2_CS = PROFrt_CS';
PROFrt2_CS = PROFrt2_CS(:);
PROFrt_CS_CI = [PROFcr0_CS_CI; PROFdr0_CS_CI; PROFcdr0_CS_CI; PROFcr10_CS_CI; PROFdr10_CS_CI; PROFcdr10_CS_CI; PROFcr18_CS_CI; PROFdr18_CS_CI; PROFcdr18_CS_CI; PROFct_CS_CI; PROFdt_CS_CI; PROFcdt_CS_CI];

F4 = figure;
F4.Position(3) = F4.Position(4)*1.61803398875;
set(gcf, 'Color', 'w');
B = bar(PROFrt_CS, 'LineWidth', 1); hold on;
B(1).FaceColor = [1 1 1];
B(1).EdgeColor = [0 0 0];
B(2).FaceColor = [0.7 0.7 0.7];
B(2).EdgeColor = [0 0 0];
B(3).FaceColor = [0.4 0.4 0.4];
B(3).EdgeColor = [0 0 0];
set(gca,'XTickLabel',{'0h', '10h','18h','BRACHYURY'});
set(gca,'FontSize',26);
er = errorbar([0.78 1 1.22 1.78 2 2.22 2.78 3 3.22 3.78 4 4.22],PROFrt2_CS,PROFrt2_CS-PROFrt_CS_CI(:,1),PROFrt_CS_CI(:,2)-PROFrt2_CS);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.5]);
set(gca,'YMinorTick','on');
xlabel('OCT4/SOX2 Ratio');
ylabel('Proficiency (%)');
export_fig PROF_OST_CS.pdf;

%%
figure;
hold on;
myviolinbs(PROFcr0_CDS,PROFcr0_CDS_BS,1,[1 1 1]);
myviolinbs(PROFdr0_CDS,PROFdr0_CDS_BS,2,[0.7 0.7 0.7]);
myviolinbs(PROFcdr0_CDS,PROFcdr0_CDS_BS,3,[0.4 0.4 0.4]);

myviolinbs(PROFcr10_CDS,PROFcr10_CDS_BS,5,[1 1 1]);
myviolinbs(PROFdr10_CDS,PROFdr10_CDS_BS,6,[0.7 0.7 0.7]);
myviolinbs(PROFcdr10_CDS,PROFcdr10_CDS_BS,7,[0.4 0.4 0.4]);

myviolinbs(PROFcr18_CDS,PROFcr18_CDS_BS,9,[1 1 1]);
myviolinbs(PROFdr18_CDS,PROFdr18_CDS_BS,10,[0.7 0.7 0.7]);
myviolinbs(PROFcdr18_CDS,PROFcdr18_CDS_BS,11,[0.4 0.4 0.4]);

myviolinbs(PROFct_CDS,PROFct_CDS_BS,13,[1 1 1]);
myviolinbs(PROFdt_CDS,PROFdt_CDS_BS,14,[0.7 0.7 0.7]);
myviolinbs(PROFcdt_CDS,PROFcdt_CDS_BS,15,[0.4 0.4 0.4]);
ylim([0 inf]);
ylim([0 0.5]);
print('PROF_OST_CDS','-dpdf');


PROFrt_CDS = [PROFcr0_CDS PROFdr0_CDS PROFcdr0_CDS; PROFcr10_CDS PROFdr10_CDS PROFcdr10_CDS; PROFcr18_CDS PROFdr18_CDS PROFcdr18_CDS; PROFct_CDS PROFdt_CDS PROFcdt_CDS];
PROFrt2_CDS = PROFrt_CDS';
PROFrt2_CDS = PROFrt2_CDS(:);
PROFrt_CDS_CI = [PROFcr0_CDS_CI; PROFdr0_CDS_CI; PROFcdr0_CDS_CI; PROFcr10_CDS_CI; PROFdr10_CDS_CI; PROFcdr10_CDS_CI; PROFcr18_CDS_CI; PROFdr18_CDS_CI; PROFcdr18_CDS_CI; PROFct_CDS_CI; PROFdt_CDS_CI; PROFcdt_CDS_CI];

F4 = figure;
F4.Position(3) = F4.Position(4)*1.61803398875;
set(gcf, 'Color', 'w');
B = bar(PROFrt_CDS, 'LineWidth', 1); hold on;
B(1).FaceColor = [1 1 1];
B(1).EdgeColor = [0 0 0];
B(2).FaceColor = [0.7 0.7 0.7];
B(2).EdgeColor = [0 0 0];
B(3).FaceColor = [0.4 0.4 0.4];
B(3).EdgeColor = [0 0 0];
set(gca,'XTickLabel',{'0h', '10h','18h','BRACHYURY'});
set(gca,'FontSize',26);
er = errorbar([0.78 1 1.22 1.78 2 2.22 2.78 3 3.22 3.78 4 4.22],PROFrt2_CDS,PROFrt2_CDS-PROFrt_CDS_CI(:,1),PROFrt_CDS_CI(:,2)-PROFrt2_CDS);    
er.Color = [0 0 0];                            
er.LineStyle = 'none';
er.LineWidth = 1;
ylim([0 0.5]);
set(gca,'YMinorTick','on');
xlabel('OCT4/SOX2 Ratio');
ylabel('Proficiency (%)');
export_fig PROF_OST_CDS.pdf;

% %% Scrambling Data to estimate significant mutual information
% 
% PROFcs_SCR = 0;
% PROFds_SCR = 0;
% PROFcds_SCR = 0;
% 
% for j = 1:10000
%     CcellsSCR = Ccells(randperm(length(Ccells)));
%     DcellsSCR = Dcells(randperm(length(Dcells)));
%     PcellsSCR = Pcells(randperm(length(Pcells)));
%     CDcellsSCR = DcellsSCR+3*CcellsSCR;
% 
%     pcs = histcounts2(CcellsSCR,PcellsSCR);
%     Pcs = pcs./sum(pcs(:));
%     pds = histcounts2(DcellsSCR,PcellsSCR);
%     Pds = pds./sum(pds(:));
%     Pc = sum(Pcs,2);
%     Pd = sum(Pds,2);
%     Ps = sum(Pcs,1);
% 
%     pcds = histcounts2(CDcellsSCR,PcellsSCR);
%     Pcds = pcds./sum(pcds(:));
%     Pcd = sum(Pcds,2);
% 
%     Ics = Pcs.*log(Pcs./(Pc*Ps));
%     MIcs = sum(Ics(:));
%     Ids = Pds.*log(Pds./(Pd*Ps));
%     MIds = sum(Ids(:));
%     Icds = Pcds.*log(Pcds./(Pcd*Ps));
%     Icds(isnan(Icds)) = 0;
%     MIcds = sum(Icds(:));
% 
%     Hs = -sum(Ps.*log(Ps));
% 
%     PROFcs_SCR = PROFcs_SCR + MIcs./Hs;
%     PROFds_SCR = PROFds_SCR + MIds./Hs;
%     PROFcds_SCR = PROFcds_SCR + MIcds./Hs;
% end
% PROFcs_SCR = PROFcs_SCR ./ 10000;
% PROFds_SCR = PROFds_SCR ./ 10000;
% PROFcds_SCR = PROFcds_SCR ./ 10000;


load('../Fig1d/Fig1dBins.mat');
Ccells = binC; %cells binned by percentile Dsource (BMP concentration)into 9 bins
Ecells = ECcells; % edge cells 
Icells = ICcells; % interior cells 
Mcells = ~(ECcells|ICcells); % cells that are neither on edge nor interior
Dcells = Ecells + 2*Mcells + 3*Icells; % indexing cells by Dedge
Pcells = PCcells; % pSMAD1/5(+) cells
CDcells = Dcells + 3*Ccells; % indexing cells by Dedge and Dsource

pcs = histcounts2(Ccells(logical(Ecells)),Pcells(logical(Ecells))); % 9x2 frequency bin of pSMAD1/5-negative/positive cells at different Dsource
Pcs = pcs./sum(pcs(:)); % frequency bin --> probability bin
pds = histcounts2(Dcells(logical(Ecells)),Pcells(logical(Ecells))); % 3x2 frequency bin of pSMAD1/5-negative/positive cells at different Dedge
Pds = pds./sum(pds(:)); %3x2 frequency bin --> 3x2 probability bin
Pc = sum(Pcs,2); %marginal probability P(Dsource)
Pd = sum(Pds,2); %marginal probability P(edge/middle/interior)
Ps = sum(Pcs,1); %marginal probability P(pSMAD1/5(-)/(+))

pcds = histcounts2(CDcells(logical(Ecells)),Pcells(logical(Ecells))); %27x2 frequency bin of pSMAD1/5-negative/positive cells at different Dsource and Dedge 
Pcds = pcds./sum(pcds(:)); %27x2 frequency bin --> 27x2 probability bin
Pcd = sum(Pcds,2); %27x1 marginal probability P(Dsource and Dedge)

Ics = Pcs.*log(Pcs./(Pc*Ps));
MIcs = sum(Ics(:)); % Mutual Information btwn Dsource and pSMAD1/5
Ids = Pds.*log(Pds./(Pd*Ps));
MIds = sum(Ids(:)); % Mutual Information btwn Dedge and pSMAD1/5
Icds = Pcds.*log(Pcds./(Pcd*Ps));
Icds(isnan(Icds)) = 0;
MIcds = sum(Icds(:)); % Mutual Information btwn (Dsource AND Dedge) and pSMAD1/5

Hs = -sum(Ps.*log(Ps)); % Entropy of pSMAD1/5

PROFcs_E = MIcs./Hs; % Proficiency btwn Dsource and pSMAD1/5
PROFds_E = MIds./Hs; % Proficiency btwn Dedge and pSMAD1/5
PROFcds_E = MIcds./Hs; % Proficiency btwn (Dsource AND Dedge) and pSMAD1/5


pcs = histcounts2(Ccells(logical(Icells)),Pcells(logical(Icells))); % 9x2 frequency bin of pSMAD1/5-negative/positive cells at different Dsource
Pcs = pcs./sum(pcs(:)); % frequency bin --> probability bin
pds = histcounts2(Dcells(logical(Icells)),Pcells(logical(Icells))); % 3x2 frequency bin of pSMAD1/5-negative/positive cells at different Dedge
Pds = pds./sum(pds(:)); %3x2 frequency bin --> 3x2 probability bin
Pc = sum(Pcs,2); %marginal probability P(Dsource)
Pd = sum(Pds,2); %marginal probability P(edge/middle/interior)
Ps = sum(Pcs,1); %marginal probability P(pSMAD1/5(-)/(+))

pcds = histcounts2(CDcells(logical(Icells)),Pcells(logical(Icells))); %27x2 frequency bin of pSMAD1/5-negative/positive cells at different Dsource and Dedge 
Pcds = pcds./sum(pcds(:)); %27x2 frequency bin --> 27x2 probability bin
Pcd = sum(Pcds,2); %27x1 marginal probability P(Dsource and Dedge)

Ics = Pcs.*log(Pcs./(Pc*Ps));
Ics(isnan(Ics)) = 0;
MIcs = sum(Ics(:)); % Mutual Information btwn Dsource and pSMAD1/5
Ids = Pds.*log(Pds./(Pd*Ps));
Ids(isnan(Ids)) = 0;
MIds = sum(Ids(:)); % Mutual Information btwn Dedge and pSMAD1/5
Icds = Pcds.*log(Pcds./(Pcd*Ps));
Icds(isnan(Icds)) = 0;
MIcds = sum(Icds(:)); % Mutual Information btwn (Dsource AND Dedge) and pSMAD1/5

Hs = -sum(Ps.*log(Ps)); % Entropy of pSMAD1/5

PROFcs_I = MIcs./Hs; % Proficiency btwn Dsource and pSMAD1/5
PROFds_I = MIds./Hs; % Proficiency btwn Dedge and pSMAD1/5
PROFcds_I = MIcds./Hs; % Proficiency btwn (Dsource AND Dedge) and pSMAD1/5

Nsample = round(length(Dcells)/3);
figure;
histogram(Dcells); hold on;
plot([0.5 3.5], [Nsample Nsample], 'k--');
ylabel('# of Cells');
xticks(1:3);
xticklabels({'Edge','Middle','Interior'});
print('PROF_dsampling','-dpdf');

% Note here that cells at edges of device have been filtered out, since
% there are no comparable interior cells at those regions

Nsample = round(length(xC)/9);
figure;
histogram(xC,linspace(min(xC),max(xC),10)); hold on;
plot([min(xC) max(xC)], [Nsample Nsample], 'k--');
xlim([min(xC) max(xC)]);
ylabel('# of Cells');
xlabel('Dsource')
print('PROF_csampling','-dpdf');

Nsample = round(length(xC)/27);
figure;
histogram(xC(logical(Icells)),linspace(min(xC),max(xC),10)); hold on;
histogram(xC(logical(Mcells)),linspace(min(xC),max(xC),10));
histogram(xC(logical(Ecells)),linspace(min(xC),max(xC),10));
plot([100 1000], [Nsample Nsample], 'k--');
xlim([min(xC) max(xC)]);
ylabel('# of Cells');
xlabel('Dsource')
legend('Interior','Middle','Edge');
print('PROF_cdsampling','-dpdf');

Nsample = round(length(xC)/27);
figure;
histogram(xC(logical(Icells)),linspace(min(xC),max(xC),10)); hold on;
plot([100 1000], [Nsample Nsample], 'k--');
ylabel('# of Cells');

xlim([min(xC) max(xC)]);
xlabel('Dsource')
legend('Interior');
print('PROF_cdsamplingI','-dpdf');

Nsample = round(length(xC)/27);
figure;
histogram(xC(logical(Mcells)),linspace(min(xC),max(xC),10)); hold on;
plot([100 1000], [Nsample Nsample], 'k--');
ylabel('# of Cells');

xlim([min(xC) max(xC)]);
xlabel('Dsource')
legend('Middle');
print('PROF_cdsamplingM','-dpdf');

Nsample = round(length(xC)/27);
figure;
histogram(xC(logical(Ecells)),linspace(min(xC),max(xC),10)); hold on;
plot([100 1000], [Nsample Nsample], 'k--');
ylabel('# of Cells');

xlim([min(xC) max(xC)]);
xlabel('Dsource')
legend('Edge');
print('PROF_cdsamplingE','-dpdf');
