clear; clc; close all;
addpath('../altmany-export_fig-cafc7c5/');
addpath('../Fiji_scripts/');

nodes = trackmateSpots('TLs3_backtrackTcells.xml');
x = nodes.POSITION_X(nodes.FRAME==4);
y = nodes.POSITION_Y(nodes.FRAME==4);
T = nodes.MEAN_INTENSITY03(nodes.FRAME==116);

nodes0 = trackmateSpots('TLs3_manualsegmentation.xml');
x0 = nodes0.POSITION_X(nodes0.FRAME==4);
y0 = nodes0.POSITION_Y(nodes0.FRAME==4);

X = [x;x0];
Y = [y;y0];

rpoints = 30;
points = rand(100000,2)*1023+1;
emptypoints = zeros(length(points),1);
for p = 1:length(emptypoints)
    emptypoints(p) = all((points(p,1)-X).^2 + (points(p,2)-Y).^2 > rpoints.^2);
end
ep = find(emptypoints);

distfromedge0 = zeros(length(x0),1);
for j = 1:length(distfromedge0)
    d = (x0(j) - points(ep,1)).^2 +...
        (y0(j) - points(ep,2)).^2;
    distfromedge0(j) = sqrt(min(d))-rpoints;
end
distfromedge0(distfromedge0<0)=0;
maxdist =max(distfromedge0);

distfromedge = zeros(length(x),1);
for j = 1:length(distfromedge)
    d = (x(j) - points(ep,1)).^2 +...
        (y(j) - points(ep,2)).^2;
    distfromedge(j) = sqrt(min(d))-rpoints;
end
distfromedge(distfromedge<0)=0;

%T-negative cells
x1 = x0; y1 = y0;
for i = 1:length(x)
    [~,I] = min(sqrt((x0-x(i)).^2 + (y0-y(i)).^2));
    ind(i)=I;
end
x1(ind)=[];
y1(ind)=[];

distfromedge1 = zeros(length(x1),1);
for j = 1:length(distfromedge1)
    d = (x1(j) - points(ep,1)).^2 +...
        (y1(j) - points(ep,2)).^2;
    distfromedge1(j) = sqrt(min(d))-rpoints;
end
distfromedge1(distfromedge1<0)=0;

distfromedge = distfromedge.*1.3;
distfromedge0 = distfromedge0.*1.3;
distfromedge1 = distfromedge1.*1.3;


figure;
H1 = histogram(distfromedge0,0:15:150,'FaceColor',[0.7 0.7 0.7]);
hold on;
H2 = histogram(distfromedge,0:15:150,'FaceColor',[0.2 0.6 1]);
xlabel('Initial Distance From Edge at 0 Hours (m)')
legend('All Cells','T+ Cells at 18 Hours')
set(gca,'FontSize',16);
H1.FaceAlpha = 1;
H2.FaceAlpha = 1;
xlim([0 135]);
ylim([0 230]);
set(gca,'XTick',0:30:150);
set(gca,'YTick',0:50:200);
set(gca,'XMinorTick','on')
set(gca,'YMinorTick','on')
%export_fig('backtrackTcells.pdf');

[f1,pts1] = ksdensity(distfromedge1);
[f,pts] = ksdensity(distfromedge);
[f0,pts0] = ksdensity(distfromedge0);

f = f/max(f);
f = f.*length(distfromedge)./length(distfromedge0);
f1 = f1/max(f1);
f1 = f1.*length(distfromedge1)./length(distfromedge0);
f0 = f0/max(f0);



[~,pts1i] = min(abs(distfromedge1-pts1),[],2);
[~,ptsi] = min(abs(distfromedge-pts),[],2);


% [~,edges,~] = histcounts(distfromedge0,20);
% [N1,~,bins1] = histcounts(distfromedge1,edges);
% [N,~,bins] = histcounts(distfromedge,edges);
% N = N'./max(N1);
% N1 = N1'./max(N1);

figure; hold on;
scatter(1+0.8*(rand(size(distfromedge1))-0.5).*f1(pts1i)',distfromedge1,30,'MarkerEdgeColor',[0.7 0.7 0.7],'MarkerFaceColor',[0.7 0.7 0.7],'MarkerEdgeAlpha',0.7,'MarkerFaceAlpha',0.5);
scatter(2+0.8*(rand(size(distfromedge))-0.5).*f(ptsi)',distfromedge,30,'MarkerEdgeColor',[0.2 0.6 1],'MarkerFaceColor',[0.2 0.6 1],'MarkerEdgeAlpha',0.7,'MarkerFaceAlpha',0.5);
xlim([0.25,2.75]);

% rectangle('Position',[0.98 prctile(distfromedge1,25) 0.04 prctile(distfromedge1,75)-prctile(distfromedge1,25)],'FaceColor','k');
% plot([1 1],[prctile(distfromedge1,5) prctile(distfromedge1,95)],'k-','LineWidth',2);
% scatter(1,prctile(distfromedge1,50),'w','filled');
% 
% rectangle('Position',[1.98 prctile(distfromedge,25) 0.04 prctile(distfromedge,75)-prctile(distfromedge,25)],'FaceColor','k');
% plot([2 2],[prctile(distfromedge,5) prctile(distfromedge,95)],'k-','LineWidth',2);
% scatter(2,prctile(distfromedge,50),'w','filled');

% DISTfromedge = [distfromedge1;distfromedge];
% g = [zeros(size(distfromedge1));ones(size(distfromedge))];
% boxplot(DISTfromedge,g,'BoxStyle','filled','Colors','k','Symbol','');

figure;
hold on;
patch([1+0.3*f0';1-0.3*flipud(f0')],[pts0';flipud(pts0')],[0.7 0.7 0.7],'LineWidth',1);
patch([2+0.3*f';2-0.3*flipud(f')],[pts';flipud(pts')],[0.2 0.6 1],'LineWidth',1);
xlim([0 3]);
ylim([0 inf]);

rectangle('Position',[0.98 prctile(distfromedge0,25) 0.04 prctile(distfromedge0,75)-prctile(distfromedge1,25)],'FaceColor','k');
plot([1 1],[prctile(distfromedge0,5) prctile(distfromedge0,95)],'k-','LineWidth',2);
scatter(1,prctile(distfromedge0,50),'w','filled');

rectangle('Position',[1.98 prctile(distfromedge,25) 0.04 prctile(distfromedge,75)-prctile(distfromedge,25)],'FaceColor','k');
plot([2 2],[prctile(distfromedge,5) prctile(distfromedge,95)],'k-','LineWidth',2);
scatter(2,prctile(distfromedge,50),'w','filled');

