%% Supp Fig 16hi %%
% Steven Zwick, 2017 %

% Unit Conversion for all images -- pixel:micron = 1:1.3 

clear; close all; clc;
addpath('../altmany-export_fig-5be2ca4');

%% Load Image Segmentation Results
load uf-20170218.mat;
Idapi = imread('uf-20170218-DAPI.tif');
Idapi(Idapi==0) = min(Idapi(Idapi~=0)); % get rid of 0's from rotating image
Idapi2 = double(Idapi);
Idapis = imread('uf-20170218-DAPIscale.tif');
Idapis(Idapis==0) = min(Idapis(Idapis~=0)); % get rid of 0's from rotating image
IT = imread('uf-20170218-T.tif');
IT2 = double(IT);
IT(IT==0) = min(IT(IT~=0)); % get rid of 0's from rotating image
ITs = imread('uf-20170218-Tscale.tif');
ITs(ITs==0) = min(ITs(ITs~=0)); % get rid of 0's from rotating image
x = handles.Measurements.Nuclei.Location_Center_X;
x = x{1};
y = handles.Measurements.Nuclei.Location_Center_Y;
y = y{1};
DAPI = handles.Measurements.Nuclei.Intensity_UpperQuartileIntensity_DAPI;
DAPI = DAPI{1}.*2^16; %16 bit pixel values
T = handles.Measurements.Nuclei.Intensity_UpperQuartileIntensity_T;
T = T{1}.*2^16; %16 bit pixel values

%% Show Image Segmentation Results
Iseg = imread('uf-20170218-DAPI-seg1.tiff');
Icolor = label2rgb(Iseg,'jet','k','shuffle');
imwrite(Icolor,'uf-20170218-seg_color.tiff');

% Iboundaries = zeros(size(Iseg));
% for i = 1:max(Iseg(:))
%     B = bwboundaries(Iseg==i);
%     B = B{1};
%     B = sub2ind(size(Iseg),B(:,1),B(:,2));
%     Iboundaries(B) = 1;
% end
%save('Iboundaries.mat','Iboundaries');

load Iboundaries.mat
Idapiboundaries = cat(3,imadjust(Idapi),imadjust(Idapi),imadjust(Idapi));
Idapiboundaries(find(Iboundaries)) = min(Idapiboundaries(:));
Idapiboundaries(find(Iboundaries)+length(Iboundaries(:))) = max(Idapiboundaries(:));
Idapiboundaries(find(Iboundaries)+2*length(Iboundaries(:))) = min(Idapiboundaries(:));
imwrite(Idapiboundaries,'uf-20170218-seg_boundaries.tiff');

%% Crop Images
xl = 127;
xr = 961;
yt = 15;
yb = 1011;
xc = x-(xl-1);
yc = y-(yt-1);

Idapic = Idapi(yt:yb,xl:xr);
ITc = IT(yt:yb,xl:xr);
imwrite(Idapic,'uf-20170218-DAPI_crop.tiff');
imwrite(ITc,'uf-20170218-T_crop.tiff');

%% Filter out Bad 'Cells' from Image Segmentation Results

pdf_normmixture = @(x,p,mu1,mu2,sigma1,sigma2) ...
                     p*normpdf(x,mu1,sigma1) + (1-p)*normpdf(x,mu2,sigma2);
pStart = .7;
muStart = quantile(log(DAPI),[.25 .75]);
sigmaStart = sqrt(var(log(DAPI)))./2;
start = [pStart muStart sigmaStart sigmaStart];
lb = [0 -Inf -Inf 0 0];
ub = [1 Inf Inf Inf Inf];

options = statset('MaxIter',1000, 'MaxFunEvals',1000);
paramEsts = mle(log(DAPI), 'pdf',pdf_normmixture, 'start',start, ...
                      'lower',lb, 'upper',ub, 'options',options);

xgrid = linspace(0.9*min(log(DAPI)),1.1*max(log(DAPI)),200);
pdfgrid = pdf_normmixture(xgrid,paramEsts(1),paramEsts(2),paramEsts(3),paramEsts(4),paramEsts(5));
pdfdiff = paramEsts(1).*normpdf(xgrid,paramEsts(2),paramEsts(4))-(1-paramEsts(1)).*normpdf(xgrid,paramEsts(3),paramEsts(5));
minloc = find(pdfdiff<0 & xgrid>paramEsts(2),1);

DAPIcutoff = xgrid(minloc);
keepcells = find((log(DAPI) > DAPIcutoff) & xc>15 & xc<(xr-xl+1-15));
xF = x(keepcells);
yF = y(keepcells);
xcF = xc(keepcells);
ycF = yc(keepcells);
DAPIF = DAPI(keepcells);
TF = T(keepcells); 

%% Show Filtered Segmentation Results

histogram(log(DAPI),'Normalization','pdf'); hold on;
set(gcf, 'Color', 'w');
set(gcf, 'Position', get(0, 'Screensize'));
plot(xgrid,pdfgrid,'-','LineWidth',1);
plot([DAPIcutoff;DAPIcutoff],[0;10],'k--');
xlim([6,7.3]);
xlabel('Log Mean DAPI Signal');
ylabel('Probability Density');
legend('Segmentation Values','Bimodal Gaussian Fit','Segmentation Filter Cutoff');
h = gcf;
set(h,'PaperPositionMode','Auto','PaperUnits','points','PaperSize',[1440, 900])
set(gca,'FontSize',26);
print('uf-20170218_filtercutoff.pdf','-dpdf');
close;

Isegf = zeros(size(Iseg));
Isegf(ismember(Iseg,keepcells)) = Iseg(ismember(Iseg,keepcells));
Isegf  = Isegf(yt:yb,xl:xr);
Icolorf = label2rgb(Isegf,'jet','k','shuffle');
imwrite(Icolorf,'uf-20170218-segfilt_color.tiff');

% Iboundariesf = zeros(size(Iseg));
% for i = 1:length(keepcells)
%     i
%     B = bwboundaries(Isegf==keepcells(i));
%     B = B{1};
%     B = sub2ind(size(Iseg),B(:,1),B(:,2));
%     Iboundariesf(B) = 1;
% end
% save('Iboundariesf.mat','Iboundariesf');

load Iboundariesf.mat
Iboundariesf  = Iboundariesf(yt:yb,xl:xr);
Idapiboundariesf = cat(3,imadjust(Idapic),imadjust(Idapic),imadjust(Idapic));
Idapiboundariesf(find(Iboundariesf)) = min(Idapiboundariesf(:));
Idapiboundariesf(find(Iboundariesf)+length(Iboundariesf(:))) = max(Idapiboundariesf(:));
Idapiboundariesf(find(Iboundariesf)+2*length(Iboundariesf(:))) = min(Idapiboundariesf(:));
imwrite(Idapiboundariesf,'uf-20170218-segfilt_boundaries.tiff');

figure;
imshow(imadjust(Idapi)); 
hold on;
scatter(x,y);
scatter(xF,yF);
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
ylim([0 1024])
export_fig uf-20170218_filteredcells.pdf;
close;

%% Calculate Distance from Edge
rpoints = 27; % "empty" points have no cells within a radius of 'rpoints'
points = rand(100000,2)*(1024+rpoints)-rpoints;
emptypoints = zeros(length(points),1);
for p = 1:length(emptypoints)
    emptypoints(p) = all((points(p,1)-xF).^2 + (points(p,2)-yF).^2 > rpoints.^2);
end
points = [points;[843,932];];
emptypoints = [emptypoints;1];
ep = find(emptypoints);

distfromedge = zeros(length(xF),1);
for j = 1:length(distfromedge)
    d = (xF(j) - points(ep,1)).^2 +...
        (yF(j) - points(ep,2)).^2;
    distfromedge(j) = sqrt(min(d))-rpoints;
end
distfromedge(distfromedge<0)=0;
maxdist =max(distfromedge);
Ecells = distfromedge<97.5; %exterior cells
Icells = distfromedge>217.5; %interior cells

%% Show Distance from Edge Results
figure(2);
imshow(imadjust(Idapi),[]); 
hold on;
scatter(points(ep,1),points(ep,2),'r.');
scatter(xF,yF,'b.');
legend('Empty Points','Cells');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
export_fig uf-20170218_emptycells.pdf;
close;

figure(65);
ax1 = axes;
imshow(imadjust(Idapic)); 
set(gcf, 'Position', get(0, 'Screensize'));
hold on;
S = scatter(xcF,ycF,25);
S.CData = [1-distfromedge./maxdist,zeros(size(distfromedge)),ones(size(distfromedge))];
ax2 = axes;
ax2.FontSize = 26;
ax2.Visible = 'off';
C = colorbar(ax2);
bmmap = [(1:-0.01:0)',zeros(101,1),ones(101,1)];
colormap(bmmap);
ax2.Position = ax1.Position;
C.Location = 'eastoutside';
ylabel(C,'Distance from Edge (m)');
C.Direction = 'reverse';
C.Ticks = [0 100./maxdist 200./maxdist 300./maxdist];
C.TickLabels = {'0', '100','200','300'};
export_fig uf-20170218_edgedist.pdf;
close;

figure(65);
imshow(imadjust(Idapic)); 
hold on;
scatter(xcF(Ecells),ycF(Ecells),'mo');
scatter(xcF(Icells),ycF(Icells),'bo');
legend('d < 130m','d > 290 m')
export_fig uf-20170218_edgedist_cutoffs.pdf;
close;

%% Calibrate Local Gradient Levels
Iconc = double(imread('uf-20170218-grad.tif'));
Iconcmean = mean(Iconc,1);
concmean = (Iconcmean-min(Iconcmean))./range(Iconcmean);
cl = 34;
cr = 826;
cx = round(xcF-cl);
cx(cx<1) = 1;
cx(cx>792) = 792;
concfilt = imgaussfilt(concmean,10);
conc = concfilt(cx)';  


%% Show Gradient Calibration Results
concfit = find(concmean>0.05,1):(find(concmean>0.95,1)-1);
concparam = polyfit(concfit.*1.3,Iconcmean(concfit),1);

figure;
set(gcf, 'Color', 'w');
set(gcf, 'Position', get(0, 'Screensize'));
shadedErrorBar((0:length(Iconcmean)-1).*1.3,Iconcmean,std(Iconc));
hold on;
concplot = plot((0:length(Iconcmean)-1).*1.3,Iconcmean,'k','LineWidth',1);
zeroset = plot([0,length(Iconcmean)-1].*1.3,[min(Iconcmean),min(Iconcmean)],'r--','LineWidth',1);
oneset = plot([0,length(Iconcmean)-1].*1.3,[max(Iconcmean),max(Iconcmean)],'r--','LineWidth',1);
xlim([0,1030]);
ylabel('Fluorescence Level');
xlabel('Channel Position (m)');
concfitplot = plot((concfit).*1.3, concparam(1).*(concfit).*1.3 + concparam(2),'b-','LineWidth', 1);
plot([concfit(1).*1.3;concfit(1).*1.3],[min(Iconcmean);max(Iconcmean)],'k-.');
plot([concfit(end).*1.3;concfit(end).*1.3],[min(Iconcmean);max(Iconcmean)],'k-.');
cresidual = Iconcmean(concfit)-(concparam(1).*(concfit).*1.3 + concparam(2));
ctotal = (length(concfit)-1) * var(Iconcmean(concfit));
Rsq = 1-sum(cresidual.^2)/ctotal;
legend([concplot,concfitplot],'Fluorescein Intensity','Linear Fit', 'Location','east'); 
text(500,5*10^4,'R^2 = 0.995','FontSize',26);
text(50,0.4*10^4,'c = 0','FontSize',20,'Color','r');
text(900,6.4*10^4,'c = 1','FontSize',20,'Color','r');
text(220,6.7*10^4,'c = 0.05','FontSize',14,'Color','k');
text(780,6.7*10^4,'c = 0.95','FontSize',14,'Color','k');
h = gcf;
pos = get(h,'Position');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
set(h,'PaperPositionMode','Auto','PaperUnits','points','PaperSize',[1440, 900])
print('uf-20170218_gradfit.pdf','-dpdf');
close;

figure(65);
ax1 = axes;
imshow(imadjust(Idapic)); 
set(gcf, 'Position', get(0, 'Screensize'));
hold on;
S = scatter(xcF,ycF,25);
S.CData = [zeros(size(conc)),conc,zeros(size(conc))];
ax2 = axes;
ax2.FontSize = 26;
ax2.Visible = 'off';
C = colorbar(ax2);
gmap = [zeros(101,1),(0:0.01:1)',zeros(101,1)];
colormap(gmap);
ax2.Position = ax1.Position;
C.Location = 'eastoutside';
ylabel(C,'Local Concentration');
export_fig uf-20170218_gradlevels.pdf;
close;

%% Subtracting Background Fluorescence (assuming uniform background)
[~,Idapidensity, Idapimesh,~] = kde(Idapi2(:),5000);
[~,Idapimaxloc] = max(Idapidensity(Idapimesh<1050));
dapibackground = Idapimesh(Idapimaxloc);
DAPIN = DAPIF - dapibackground;
DAPIN(DAPIN<0) = 0;

% [~,DAPIdensity, DAPImesh,~] = kde(DAPIN(:),5000);
% [~,DAPImaxloc] = max(DAPIdensity(DAPImesh<1050));
% DAPImode = DAPImesh(DAPImaxloc);
% DAPIN = DAPIN./DAPImode;

[~,ITdensity, ITmesh,~] = kde(IT2(:),5000);
[~,ITmaxloc] = max(ITdensity(ITmesh<1050));
Tbackground = ITmesh(ITmaxloc);
TN = TF - Tbackground;
TN(TN<0) = 0;

% [~,Tdensity, Tmesh,~] = kde(TN(:),5000);
% [~,Tmaxloc] = max(Tdensity(Tmesh<1050));
% Tmode = Tmesh(Tmaxloc);
% TN = TN./Tmode;

%% Showing Background Fluorescence Results 
plot(ITmesh,ITdensity,'LineWidth',2);
hold on;
plot([Tbackground Tbackground],[0 4*10^-3],'r--','LineWidth',2);
legend('Kernel Density Estimation','Background Intensity');
xlim([700,2500]);
xlabel('Pixel Intensity');
ylabel('Probability Density');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
export_fig uf-20170218_Tbackground.pdf;
close;

%% Determine Which Cells are T+
TFN = TN./DAPIN;
[~,TFNdensity, TFNmesh, ~] = kde(TFN,5000);
Tmaxloc = find(TFNdensity==max(TFNdensity));
Tmax = TFNmesh(Tmaxloc);
TFNhalfnull =Tmax-TFN(TFN<=Tmax);
param = fitdist(TFNhalfnull,'HalfNormal');
fullnulldist = makedist('Normal',Tmax,param.sigma);
Tcells = TFN>(Tmax+10.*param.sigma);

%% Show T+ Cell Identification

[~,TNdensity, TNmesh, ~] = kde(TN,5000);
plot(TNmesh,TNdensity,'LineWidth',2);
xlim([0,2000]);
xlabel('T Level');
ylabel('Probability Density');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
export_fig uf-20170218_TFkde.pdf;
close;

plot(TFNmesh,TFNdensity,'LineWidth',2);
xlim([0,10]);
xlabel('T/DAPI Level');
ylabel('Probability Density');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
export_fig uf-20170218_TFNkde.pdf;
close;

plot(TFNmesh,TFNdensity,'LineWidth',2);
hold on;
plot([Tmax,Tmax],[0,1],'r--');
xlim([0,10]);
xlabel('T/DAPI Level');
ylabel('Probability Density');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
export_fig uf-20170218_TFNkdemax.pdf;
close;

R1 = plot(TFNmesh,TFNdensity,'LineWidth',2);
hold on;
plot([Tmax,Tmax],[0,1],'r--');
R2 = plot(0:0.01:Tmax,pdf(fullnulldist,0:0.01:Tmax).*max(TFNdensity)./pdf(fullnulldist,Tmax),'r-.', 'LineWidth',2);
xlim([0,10]);
xlabel('T/DAPI Level');
ylabel('Probability Density');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
legend([R1,R2],'Kernel Density Estimate','Half-Gaussian Fit')
export_fig uf-20170218_TFNkdehalfnull.pdf;
close;

R1 = plot(TFNmesh,TFNdensity,'LineWidth',2);
hold on;
plot([Tmax,Tmax],[0,1],'r--');
R2 = plot(TFNmesh,pdf(fullnulldist,TFNmesh).*max(TFNdensity)./pdf(fullnulldist,Tmax),'r-.', 'LineWidth',2);
xlim([0,10]);
xlabel('T/DAPI Level');
ylabel('Probability Density');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
legend([R1,R2],'Kernel Density Estimate','Null Distribution')
export_fig uf-20170218_TFNkdemaxnull.pdf;
close;

R1 = plot(TFNmesh,TFNdensity,'LineWidth',2);
hold on;
plot([Tmax,Tmax],[0,1],'r--');
R2 = plot(TFNmesh,pdf(fullnulldist,TFNmesh).*max(TFNdensity)./pdf(fullnulldist,Tmax),'r-.', 'LineWidth',2);
R3 = plot([Tmax+10.*param.sigma,Tmax+10.*param.sigma],[0,4],'k-.','LineWidth',2);
xlim([0,10]);
xlabel('T/DAPI Level');
ylabel('Probability Density');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
legend([R1,R2,R3],'Kernel Density Estimate','Null Distribution','10\sigma Outside Null Distribution')
export_fig uf-20170218_TFNkdecutoff.pdf;
close;

figure;
imshow(imadjust(ITc)); 
hold on;
plot(xcF(Tcells),ycF(Tcells),'ro');
set(gcf, 'Position', get(0, 'Screensize'));
legend('T+ cells')
set(gca,'FontSize',26);
export_fig uf-20170218_Tcutoffcells.pdf;
close;

%% Bin Cells by Concentration
conccutoff = [min(conc(Icells)),max(conc(Icells))];
Ccells = conc>=conccutoff(1) & conc<=conccutoff(2);
concC = conc(Ccells);
xcC = xcF(Ccells);
ycC = ycF(Ccells);
TC = TN(Ccells);
ECcells = Ecells(Ccells);
ICcells = Icells(Ccells);
TCcells = Tcells(Ccells);

Acells = ECcells | ICcells;
concA = concC(Acells);
xcA = xcC(Acells);
ycA = ycC(Acells);
TA = TC(Acells);
EAcells = ECcells(Acells);
IAcells = ICcells(Acells);
TAcells = TCcells(Acells);
TEcells = TAcells & EAcells;
TIcells = TAcells & IAcells;

[~,Tdensity, Tmesh,~] = kde(TA(:),5000);
[~,Tmaxloc] = max(Tdensity(Tmesh<1050));
Tmode = Tmesh(Tmaxloc);
TA = TA./Tmode;

nbins = 5;
[~,edges,bin] = histcounts(concA,linspace(conccutoff(1),conccutoff(2),nbins+1));
edgecenters = (edges(2:nbins+1)+edges(1:nbins))./2;

%% Show Cells Picked for Analysis
ITcs = imread('uf-20170218-T_cropscale.tif');
figure;
imshow(imadjust(ITcs)); 
hold on;
scatter(xcA(EAcells),ycA(EAcells),'mo');
scatter(xcA(IAcells),ycA(IAcells),'bo');
legend('d < 130m','d > 290 m');
export_fig uf-20170218_analyzedcells.pdf;
close;

%% Find Mean T Levels of Exterior and Interior Cells at each Concentration Bin
TE = zeros(1,nbins);
TI = zeros(1,nbins);
TEci = zeros(2,nbins);
TIci = zeros(2,nbins);
for i = 1:nbins    
    TE(i) = mean(TA(bin==i & EAcells));
    TI(i) = mean(TA(bin==i & IAcells));
    [~,~,TEci(:,i),~] = ttest(TA(bin==i & EAcells));
    [~,~,TIci(:,i),~] = ttest(TA(bin==i & IAcells));
end

F4 = figure(4);
%set(gcf, 'Position', get(0, 'Screensize'));
F4.Position(3) = F4.Position(4)*1.61803398875*0.8;
set(F4, 'Color', 'w');
PI = errorbar(edgecenters,TI,TI-TIci(1,:),TIci(2,:)-TI,'-o','LineWidth',2,'Color','k','MarkerSize',2,'MarkerFaceColor','k');
hold on;
%PI = errorbar(edgecenters,TI,TI-TIci(1,:),TIci(2,:)-TI,'-','LineWidth',3,'Color','k','MarkerFaceColor','k');
PE = errorbar(edgecenters+0.05.*diff(edgecenters(1:2)),TE,TE-TEci(1,:),TEci(2,:)-TE,'-o','LineWidth',2,'Color',[0.5 0.5 0.5],'MarkerSize',2);
%PE = errorbar(edgecenters+0.05.*diff(edgecenters(1:2)),TE,TE-TEci(1,:),TEci(2,:)-TE,'-','LineWidth',3,'Color',[0.5 0.5 0.5]);
set(gca,'LineWidth',2);
set(gca,'FontSize',30);
xlim([0.1 0.8]);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pctx = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pctx];
set(gca,'xticklabel',new_xticks)
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Mean T Level');
%legend([PE,PI],'Edge of Colony','Interior of Colony', 'Location', 'northoutside');
export_fig uf-20170218_gradThist.pdf;
close;

% %% Deviations from Mean 
% TE = zeros(1,nbins);
% TI = zeros(1,nbins);
% TEci = zeros(2,nbins);
% TIci = zeros(2,nbins);
% for i = 1:nbins    
%     TE(i) = mean(TdapiA(bin==i & EAcells));
%     TI(i) = mean(TdapiA(bin==i & IAcells));
%     [~,~,TEci(:,i),~] = ttest(TdapiA(bin==i & EAcells));
%     [~,~,TIci(:,i),~] = ttest(TdapiA(bin==i & IAcells));
% end
% 
% F4 = figure(4);
% set(gcf, 'Position', get(0, 'Screensize'));
% set(F4, 'Color', 'w');
% PI = errorbar(edgecenters,TI,TI-TIci(1,:),TIci(2,:)-TI,'b-o','LineWidth',2);
% hold on;
% PE = errorbar(edgecenters+0.05.*diff(edgecenters(1:2)),TE,TE-TEci(1,:),TEci(2,:)-TE,'m-o','LineWidth',2);
% a=cellstr(num2str(get(gca,'xtick')'*100)); 
% pctx = char(ones(size(a,1),1)*'%'); 
% new_xticks = [char(a),pctx];
% set(gca,'xticklabel',new_xticks)
% ax = gca;
% ax.XAxis.MinorTick = 'on';
% ax.YAxis.MinorTick = 'on';
% xlabel('Gradient Level');
% ylabel('Mean Brachyury Level');
% legend([PE,PI],'Edge of Colony','Interior of Colony', 'Location', 'northeast');
% set(gca,'FontSize',26);
% export_fig uf-20170218_gradThist.pdf;
% close;

%% Find Fraction of T+ Exterior and Interior Cells at each Concentration Bin
TE = zeros(nbins,1);
TI = zeros(nbins,1);
TEci = zeros(nbins,2);
TIci = zeros(nbins,2);
for i = 1:nbins
    [TE(i), TEci(i,:)] = binofit(sum(bin==i & TEcells),sum(bin==i & EAcells));
    [TI(i), TIci(i,:)] = binofit(sum(bin==i & TIcells),sum(bin==i & IAcells));
end

F4 = figure(4);
set(F4, 'Color', 'w');
set(gcf, 'Position', get(0, 'Screensize'));
PI = errorbar(edgecenters,TI,TI-TIci(:,1),TIci(:,2)-TI,'b-o','LineWidth',2);
hold on;
PE = errorbar(edgecenters+0.05.*diff(edgecenters(1:2)),TE,TE-TEci(:,1),TEci(:,2)-TE,'m-o','LineWidth',2);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pctx = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pctx];
set(gca,'xticklabel',new_xticks)
ylim([0 0.7]);
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Probability of T+ Cell');
legend([PE,PI],'Edge of Colony','Interior of Colony', 'Location', 'northeast');
set(gca,'FontSize',26);
export_fig uf-20170218_gradTprob.pdf;
close;

%% Show Sensitivity to T+ Cell Cutoff
%7 sigma
Tcells = TFN>(Tmax+7.*param.sigma);
TCcells = Tcells(Ccells);
TAcells = TCcells(Acells);
TEcells = TAcells & EAcells;
TIcells = TAcells & IAcells;

TE = zeros(nbins,1);
TI = zeros(nbins,1);
TEci = zeros(nbins,2);
TIci = zeros(nbins,2);
for i = 1:nbins
    [TE(i), TEci(i,:)] = binofit(sum(bin==i & TEcells),sum(bin==i & EAcells));
    [TI(i), TIci(i,:)] = binofit(sum(bin==i & TIcells),sum(bin==i & IAcells));
end

figure(4);
imshow(imadjust(ITc)); 
hold on;
plot(xcF(Tcells),ycF(Tcells),'ro');
set(gcf, 'Position', get(0, 'Screensize'));
legend('T+ cells (7\sigma cutoff)')
set(gca,'FontSize',26);
export_fig uf-20170218_Tcutoffcells_7sigma.pdf;
close;

F4 = figure(4);
set(F4, 'Color', 'w');
set(gcf, 'Position', get(0, 'Screensize'));
PI = errorbar(edgecenters,TI,TI-TIci(:,1),TIci(:,2)-TI,'b-o','LineWidth',2);
hold on;
PE = errorbar(edgecenters+0.05.*diff(edgecenters(1:2)),TE,TE-TEci(:,1),TEci(:,2)-TE,'m-o','LineWidth',2);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pctx = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pctx];
set(gca,'xticklabel',new_xticks)
ylim([0 0.8]);
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Probability of T+ Cell (7\sigma cutoff)');
legend([PE,PI],'Edge of Colony','Interior of Colony', 'Location', 'northeast');
set(gca,'FontSize',26);
export_fig uf-20170218_gradTprob_7sigma.pdf;
close;

% 13 sigma
Tcells = TFN>(Tmax+13.*param.sigma);
TCcells = Tcells(Ccells);
TAcells = TCcells(Acells);
TEcells = TAcells & EAcells;
TIcells = TAcells & IAcells;

TE = zeros(nbins,1);
TI = zeros(nbins,1);
TEci = zeros(nbins,2);
TIci = zeros(nbins,2);
for i = 1:nbins
    [TE(i), TEci(i,:)] = binofit(sum(bin==i & TEcells),sum(bin==i & EAcells));
    [TI(i), TIci(i,:)] = binofit(sum(bin==i & TIcells),sum(bin==i & IAcells));
end

figure(4);
imshow(imadjust(ITc)); 
hold on;
plot(xcF(Tcells),ycF(Tcells),'ro');
set(gcf, 'Position', get(0, 'Screensize'));
legend('T+ cells (13\sigma cutoff)')
set(gca,'FontSize',26);
export_fig uf-20170218_Tcutoffcells_13sigma.pdf;
close;

F4 = figure(4);
set(F4, 'Color', 'w');
set(gcf, 'Position', get(0, 'Screensize'));
PI = errorbar(edgecenters,TI,TI-TIci(:,1),TIci(:,2)-TI,'b-o','LineWidth',2);
hold on;
PE = errorbar(edgecenters+0.05.*diff(edgecenters(1:2)),TE,TE-TEci(:,1),TEci(:,2)-TE,'m-o','LineWidth',2);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pctx = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pctx];
set(gca,'xticklabel',new_xticks)
ylim([0 0.7]);
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Probability of T+ Cell (13\sigma cutoff)');
legend([PE,PI],'Edge of Colony','Interior of Colony', 'Location', 'northeast');
set(gca,'FontSize',26);
export_fig uf-20170218_gradTprob_13sigma.pdf;
close;


